@@ -34,6 +34,7 @@ rm qdvdauthor
 rm qslideshow
 rm qplayer
 rm qrender
+rm core*
 
 # This script cleans all sub projects for a neat and compact directory.
 cd ../configurator/; make clean 
@@ -46,22 +47,33 @@ rm i18n/*.qm
 rm CONFIG.h
 rm core*
 
-cd qslideshow/; make clean
+cd tools; make clean
+rm core*
+
+cd ../qslideshow/; make clean
 rm Makefile
 rm core*
 
 cd ../qplayer/; make clean
 rm Makefile
 rm MEDIA_CONFIG.h
-rm core
+rm core*
 
 cd ../qrender/; make clean
 rm Makefile
-rm core
+rm core*
 
-cd ..
+cd ../plugins/menuslide; make clean
+rm Makefile
+rm menuslide
+rm core*
+
+cd ../..
 rm -r .ui .moc .obj
-rm core* 
+rm core*
+
+cd ../manual; make clean
+rm core*
 
 cd ..
 sourceFiles=`cat \`find . -name "*.cpp"\` | wc -l`
