@@ -58,7 +58,7 @@ public:
   void fitDVDMenuBackground     ( QPixmap  *, int, int, QSize, int, int );
   void         setMouseCursor   ( enPointerShape );
 
-  virtual void drawBackground   ( QPixmap & );
+  virtual void drawBackground   ( QPixmap &, MenuObject *p=NULL );
   virtual void setBackground    ( QPixmap & );
   
 public slots:
