@@ -1,12 +1,15 @@
 /****************************************************************************
 ** DialogAnimation class
 **
-** Created: Mon Jun 10 22:48:00 2005
-**      by: Varol Okan using Kate
+**   Created : Mon Jun 10 22:48:00 2005
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 ****************************************************************************/
 
+#include <qpushbutton.h>
 #include <qmessagebox.h>
 #include <qtextedit.h>
 #include <qcombobox.h>
@@ -29,12 +32,12 @@ DialogAnimation::~DialogAnimation ()
 
 void DialogAnimation::initMe ( QString qsAnimation, long iFrames, float fFPS, int iType )
 {
-	char *standardProperties[] = {"rect", "visibleFromTo", "transparency", "rotate", "zoom", "scale", "shear"}; // index 0-14
-	char *frameProperties   [] = {"color", "frameWidth", "frameStyle", "frameJoin"}; // index 15-26
+	char standardProperties[][14] = {"rect", "visibleFromTo", "transparency", "rotate", "zoom", "scale", "shear"}; // index 0-14
+	char frameProperties   [][12] = {"color", "frameWidth", "frameStyle", "frameJoin"}; // index 15-26
 	//char *imageProperties [] = {"fileName", "backgroundFileName", "showBackground", "kenBurns", "pos", "blendColor", "brightness" }; // index 15-24
-	char *imageProperties   [] = {"fileName", "kenBurns", "pos", "blendColor", "brightness" }; // index 15-24
-	char *movieProperties   [] = {"frameNo"}; // index 26
-	char *textProperties    [] = {"text", "font", "textAlign", "foregroundColor", "backgroundColor"}; // index 15-27
+	char imageProperties   [][16] = {"fileName", "kenBurns", "pos", "blendColor", "brightness" }; // index 15-24
+	char movieProperties   [][10] = {"frameNo"}; // index 26
+	char textProperties    [][20] = {"text", "font", "textAlign", "foregroundColor", "backgroundColor"}; // index 15-27
 	// Note we have to synch those entries when we make the changes. I.e. 
 	// standard properties.rect has 6 variables, index 0-5 (x1, y1, x2, y2, width, height)
 	// standard properties.rotate has 1 variable, index 6 etc.
@@ -137,7 +140,7 @@ void DialogAnimation::slotAddAttribute ()
   // This function adds the set Attribute at the curren cursor position in the text edit
 	
   // The following attributes should show up as N::property.attribute=
-  char *arrayProperties[] = {"visibleFromTo", "color", "kenBurns", "startPos", "res", "blendColor", "foregroundColor", "backgroundColor", "rect", "scale", "shear", "pos" };
+  char arrayProperties[][20] = {"visibleFromTo", "color", "kenBurns", "startPos", "res", "blendColor", "foregroundColor", "backgroundColor", "rect", "scale", "shear", "pos" };
 
   uint t;
   bool bFound = false;
@@ -171,9 +174,10 @@ void DialogAnimation::slotAttribute (const QString &newText)
 	// Here we set the m_pComboAttributeSub according to the value of m_pComboAttributes
 	m_pComboAttributeSub->clear ();
 	if ( (newText == "color") || (newText == "blendColor") || (newText == "backgroundColor") || (newText == "foregroundColor") )	{
-		m_pComboAttributeSub->insertItem ( "red" );
+		m_pComboAttributeSub->insertItem ( "red"   );
 		m_pComboAttributeSub->insertItem ( "green" );
-		m_pComboAttributeSub->insertItem ( "blue" );
+		m_pComboAttributeSub->insertItem ( "blue"  );
+		m_pComboAttributeSub->insertItem ( "alpha" );
 	}
 	else if ( newText == "kenBurns" )	{
 		m_pComboAttributeSub->insertItem ( "x1" );
