@@ -475,7 +475,7 @@ void DialogCreateTemplate::slotInstall ( )
       return;
     }
     // First we should remove the current directory.
-    qsCommand += QString ( "rm -r %1\n" ).arg ( qsInstallDir );
+    qsCommand += QString ( "rm -r %1\n" ).arg ( QFile::encodeName ( qsInstallDir ) );
     //system ( qsCommand.ascii () );
   }
 
@@ -483,11 +483,11 @@ void DialogCreateTemplate::slotInstall ( )
   QFile theFile;
   QDir theDir ( qsInstallDir );
   if ( ! theDir.exists ( ) )
-    qsCommand += QString ( "mkdir -p \"%1\";\n" ).arg ( qsInstallDir );
-  qsCommand += QString ( "cd \"%1\"; tar -xzf \"%2/%3.tar.gz\"\n" ).arg ( qsPrefixDir ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
+    qsCommand += QString ( "mkdir -p \"%1\";\n" ).arg ( QFile::encodeName ( qsInstallDir ) );
+  qsCommand += QString ( "cd \"%1\"; tar -xzf \"%2/%3.tar.gz\"\n" ).arg ( QFile::encodeName ( qsPrefixDir ) ).arg ( QFile::encodeName ( Global::qsTempPath ) ).arg ( QFile::encodeName ( m_pEditFileName->text ( ) ) );
   // Last we use the same routine to install as in TemplateDownload ...
   
-  qsExecutable = QString ( "%1/execute.sh" ).arg ( Global::qsTempPath );
+  qsExecutable = QString ( "%1/execute.sh" ).arg ( QFile::encodeName ( Global::qsTempPath ) );
   theFile.setName  ( qsExecutable );
   if ( theFile.open( IO_WriteOnly ) ) {
     QTextStream stream( &theFile );
@@ -508,7 +508,7 @@ QString DialogCreateTemplate::findGuiSU ( )
   int iRet = 0;
   uint t;
   QString qsReturn;
-  QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
+  QString qsTmpOut = QFile::encodeName ( QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) ) );
   char arraySUs[3][10] = {"kdesu", "xsu", "gnomesu"};
   QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
@@ -614,10 +614,12 @@ QString DialogCreateTemplate::createTemplate ( )
   // 3) tar, gz the result
   Utils theUtils;
   QString qsCommand, qsTemplatePath;
+  QString qsFileName = QFile::encodeName ( m_pEditFileName->text ( ) );
+  QString qsTempPath = QFile::encodeName ( Global::qsTempPath );
   QDir theDir;
   int iRet = 0;
 
-  qsTemplatePath = QString ( "%1/%2%3").arg ( Global::qsTempPath ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) );
+  qsTemplatePath = QString ( "%1/%2%3").arg ( qsTempPath ).arg ( getTypePath ( ) ).arg ( qsFileName );
   if ( ! theUtils.recMkdir ( qsTemplatePath + "/background" ) )  {
     QString qsTemp;
     return qsTemp;
@@ -626,15 +628,15 @@ QString DialogCreateTemplate::createTemplate ( )
   m_pFrameProperties->ensureUniqueDropZoneName ( );
   if ( ! createTemplateXml ( qsTemplatePath ) )
     return qsTemplatePath;
-  if ( ! createBackground ( qsTemplatePath ) )
+  if ( ! createBackground  ( qsTemplatePath ) )
     return qsTemplatePath;
   
   // These two functions are for convenience ...
   //  createIndexXml ( );
   //  createWebHtml  ( );
 
-  qsTemplatePath = QString ( "%2%3").arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) );
-  qsCommand = QString ( "cd %1; tar -czf %2.tar.gz %3" ).arg( Global::qsTempPath ).arg( m_pEditFileName->text () ).arg( qsTemplatePath );
+  qsTemplatePath = QString ( "%2%3").arg ( getTypePath ( ) ).arg ( qsFileName );
+  qsCommand = QString ( "cd %1; tar -czf %2.tar.gz %3" ).arg ( qsTempPath ).arg ( qsFileName ).arg( qsTemplatePath );
   iRet = system ( qsCommand.ascii ( ) );
 
   // These two functions are for convenience ... 
@@ -643,12 +645,12 @@ QString DialogCreateTemplate::createTemplate ( )
   createWebHtml  ( );
   // This package holds index.xml, and web.html
   qsCommand = QString ( "cd %1; cp %2/thumbnail.png %3.png; tar -cjf %4.tar.bz2 index.xml web.html %5.png" ).
-    arg ( Global::qsTempPath ).
-    arg ( qsTemplatePath ).arg( m_pEditFileName->text ( ) ).arg ( m_pEditFileName->text ( ) ).
-    arg ( m_pEditFileName->text ( ) );
+    arg ( qsTempPath ).
+    arg ( qsTemplatePath ).arg( qsFileName ).arg ( qsFileName ).
+    arg ( qsFileName );
   iRet = system ( qsCommand.ascii ( ) );
 
-  qsTemplatePath = QString ( "%1/%2.tar.gz" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
+  qsTemplatePath = QString ( "%1/%2.tar.gz" ).arg ( qsTempPath ).arg ( qsFileName );
 
   return qsTemplatePath;
 }
@@ -800,7 +802,7 @@ void DialogCreateTemplate::handleMenuAudio ( QString &qsMenuXml, QString &qsTemp
 // printf ( "%s::%s::%d - [%d] = <%s>\n", __FILE__, __FUNCTION__, __LINE__, t, listSoundFiles [t].ascii ( ) );
       fileInfo.setFile ( listSoundFiles[t] );
       if ( fileInfo.exists ( ) ) {
-	qsFileName = fileInfo.fileName ( );
+	qsFileName = QFile::encodeName ( fileInfo.fileName ( ) );
 	qsTemplateFileName = QString ( "+PREFIX_DIRECTORY+/%1%2/%3" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
 	qsCommand = QString ( "cp \"%1\" \"%2/%3\"" ).arg ( listSoundFiles[t] ).arg ( qsTemplatePath ).arg ( qsFileName );
 	iRet = system ( qsCommand.ascii ( ) );
@@ -887,7 +889,7 @@ void DialogCreateTemplate::handleMenuImages ( QString &qsMenuXml, QString &qsTem
 	QString qsOrigFileName = rx1.cap ( 0 );
 	listTemp = QStringList::split ( "\"", rx1.cap ( 0 ) );
 	fileInfo.setFile ( listTemp [ 1] );
-	qsFileName = fileInfo.fileName ( );
+	qsFileName = QFile::encodeName ( fileInfo.fileName ( ) );
 	// Next we should copy the file over ...
 	qsCommand = QString ( "cp \"%1\" \"%2\"" ).arg ( listTemp[1] ).arg ( qsTemplatePath );
 	iRet = system ( qsCommand.ascii ( ) );
@@ -895,7 +897,7 @@ void DialogCreateTemplate::handleMenuImages ( QString &qsMenuXml, QString &qsTem
       else // Not found .. Oooops ...
 	qsFileName = QString ( "dummy.png" );
       
-      qsTemp = QString ( "FileName=\"+PREFIX_DIRECTORY+/%1%2/%3\"" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
+      qsTemp = QString ( "FileName=\"+PREFIX_DIRECTORY+/%1%2/%3\"" ).arg ( getTypePath ( ) ).arg ( QFile::encodeName ( m_pEditFileName->text ( ) ) ).arg ( qsFileName );
       qsImageObject.replace ( rx1, qsTemp );
       listNew.append  ( qsImageObject );
       iPos += rx.matchedLength ( );
@@ -1055,7 +1057,7 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
 
   if ( ! pInterface->qsMovieFileName.isEmpty ( ) ) {
     QString qsCommand;
-    qsCommand = QString ( "cp %1 %2/background/" ).arg ( pInterface->qsMovieFileName ).arg ( qsTemplatePath );
+    qsCommand = QString ( "cp %1 %2/background/" ).arg ( QFile::encodeName ( pInterface->qsMovieFileName ) ).arg ( qsTemplatePath );
     iRet = system ( qsCommand.ascii ( ) );
   }
 
@@ -1212,7 +1214,7 @@ void DialogCreateTemplate::slotNetworkFinished ( QNetworkOperation * )
   stat.graph(log)( x, y );
   stat.draw ( w );
 
-  QString   qsFileName = QString ( "%1/%2.tar.gz" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
+  QString   qsFileName = QFile::encodeName ( QString ( "%1/%2.tar.gz" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) ) );
   QFile     theFile  ( qsFileName );
   QFileInfo fileInfo ( qsFileName );
 
@@ -1227,7 +1229,7 @@ void DialogCreateTemplate::slotNetworkFinished ( QNetworkOperation * )
     setCursor        ( myCursor );
     Global::eventLoop.exec ( );
     theFile.close ( );
-    qsFileName = QString ( "%1/%2.tar.bz2" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) );
+    qsFileName = QFile::encodeName ( QString ( "%1/%2.tar.bz2" ).arg ( Global::qsTempPath ).arg ( m_pEditFileName->text ( ) ) );
     theFile.setName      ( qsFileName );
     fileInfo.setFile     ( qsFileName );
     if ( theFile.open ( IO_ReadOnly ) ) {
