@@ -45,7 +45,7 @@ DialogExecute::GuiBlock::GuiBlock ( )
   pButtonEdit            = NULL;
   pButtonSetAsDefault    = NULL;
   iBlockID               = -1;
-  iBlockExecuteInterface  = -1;
+  iBlockExecuteInterface = -1;
 }
 
 DialogExecute::DialogExecute(QValueList<ExecuteInterface *> listExecuteBlocks, bool bShowDialog )
@@ -59,6 +59,10 @@ DialogExecute::DialogExecute(QValueList<ExecuteInterface *> listExecuteBlocks, b
 	m_pTranscodeParent = NULL;
 	m_pTranscodeLayout = NULL;
 	m_iTranscodeOffset = 0;
+	m_pSubtitlesParent = NULL;
+	m_pSubtitlesLayout = NULL;
+	m_iSubtitlesOffset = 0;
+
 	// Here we concat all commands together ...
 	for (t=0;t<listExecuteBlocks.count();t++)	// Lets get the default commands ...
 		commandList += listExecuteBlocks[t]->listCommandList[0];
@@ -379,33 +383,48 @@ void DialogExecute::createTranscodeBlock (ExecuteInterface *pInterface, int t)
 	}
 }
 
+void DialogExecute::createSubtitlesBlock ( ExecuteInterface *pInterface, int t )
+{
+  if  ( ! m_pSubtitlesLayout )	{
+    QString qsBlockName     = pInterface->qsBlockName;
+    pInterface->qsBlockName = tr ( "Subtitles Block" );
+    m_pSubtitlesLayout      = createBlockFrame    ( m_pScrollFrame, m_pScrollFrameLayout, pInterface, t ); 
+    m_pSubtitlesParent      = m_listGroupBox.last ( );
+    pInterface->qsBlockName = qsBlockName;
+  }
+  createStandardBlock ( m_pSubtitlesParent, m_pSubtitlesLayout, pInterface, t );
+}
+
 void DialogExecute::createDVDAuthorTab   (QValueList<ExecuteInterface *> listExecuteBlocks)
 {
 	uint t;
-
 	m_listExecuteInterface = listExecuteBlocks;
+	ExecuteInterface *pExecute = NULL;
 
 	// Here we create the ScrollView and Layouts ...
-	m_pTabExpert = new QWidget( m_pTabWidget, "m_pTabExpert" );
-	tabLayout = new QGridLayout( m_pTabExpert, 1, 1, 11, 6, "tabLayout");
-
-	m_pScrollView = new QScrollView (m_pTabExpert, "ScrollView");
-
+	m_pTabExpert   = new QWidget( m_pTabWidget, "m_pTabExpert" );
+	tabLayout      = new QGridLayout( m_pTabExpert, 1, 1, 11, 6, "tabLayout");
+	m_pScrollView  = new QScrollView (m_pTabExpert, "ScrollView");
 	m_pScrollFrame = new QFrame( m_pScrollView, "m_pScrollFrame" );
 	m_pScrollFrame->setPaletteBackgroundColor( QColor( 238, 230, 234 ) );
 	m_pScrollFrame->setFrameShape( QFrame::StyledPanel );
 	m_pScrollFrame->setFrameShadow( QFrame::Raised );
 	m_pScrollFrameLayout = new QGridLayout( m_pScrollFrame, 1, 1, 11, 6, "m_pScrollFrameLayout");
 
-	for (t=0;t<listExecuteBlocks.count();t++)	{
-		// Check if this is a transoding block ...
-		if (listExecuteBlocks[t]->listSplitAt.count() > 0 )
-			createTranscodeBlock (listExecuteBlocks[t], t);
-		else
-			createStandardBlock  (m_pScrollFrame, m_pScrollFrameLayout, listExecuteBlocks[t], t);
+	for ( t=0; t<listExecuteBlocks.count ( ); t++ )  {
+	  pExecute = listExecuteBlocks[t];
+	  // Check if this is a transoding block ...
+	  //if ( pExecute->enType == ExecuteInterface::TYPE_TRANSCODING )//( pExecute->listSplitAt.count ( ) > 0 )
+	  if ( pExecute->listSplitAt.count ( ) > 0 )
+	    createTranscodeBlock ( pExecute, t );
+	  else if ( pExecute->enType == ExecuteInterface::TYPE_SUBTITLES )
+	    //createStandardBlock  ( m_pScrollFrame, m_pScrollFrameLayout, pExecute, t );
+	    createSubtitlesBlock ( pExecute, t );
+	  else // TYPE_DEFAULT
+	    createStandardBlock  ( m_pScrollFrame, m_pScrollFrameLayout, pExecute, t );
 	}
 
-	m_pScrollView->addChild (m_pScrollFrame);
+	m_pScrollView->addChild  ( m_pScrollFrame );
 
 	m_pFrameExplain = new QFrame( m_pScrollFrame, "m_pFrameExplain" );
 	m_pFrameExplain->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, m_pFrameExplain->sizePolicy().hasHeightForWidth() ) );
@@ -687,8 +706,8 @@ void DialogExecute::slotEditButtonClicked()
 	    pKeyword->setKeywords( iWhichKeyset, m_listExecuteInterface[iInterface]->listKeywords );
 	    // and finally we generate the command / header with the correct keywords ...
 	    pGuiBlock->pComboCommands->clear ( );
-	    for (i=0; i<pBlock->listCommands.count ( );
-		 pGuiBlock->pComboCommands->insertItem( pKeyword->resolvString( iWhichKeyset, pBlock->listCommands[i++] ) ) );
+	    for ( i=0; i<pBlock->listCommands.count ( ); i++ )
+		  pGuiBlock->pComboCommands->insertItem( pKeyword->resolvString( iWhichKeyset, pBlock->listCommands[i] ) );
 	    pGuiBlock->pLabelComment->setText ( pKeyword->resolvString( iWhichKeyset, pBlock->listComments[0] ) );
 	    m_pInitObject->setToolsPaths ( m_listToolsPaths );
 	    m_pInitObject->saveIniFile   ( );
