@@ -63,11 +63,14 @@ public:
   };
 
   GroupView ( QWidget *, QIconView *, DialogFiles *, SourceFileEntry *p=NULL );
+  GroupView ( QWidget *, SourceFileEntry * );
   virtual ~GroupView  ( );
 
   SourceFileEntry *sourceFileEntry ( ); // could be NULL
   void append ( void * );
 
+  QString groupName     ( );
+  void    setGroupName  ( QString & );
 protected: // member functions
   // Overloaded function
   virtual QDragObject *dragObject( );
@@ -114,7 +117,7 @@ class DialogFiles : public uiDialogFiles
     DirItem ( QListView *, QString );
     DirItem ( DirItem *,   QString );
     virtual ~DirItem ( ) { };
-    
+
     virtual void setOpen ( bool );
     QString  dir ( );
     DirItem *findSubDir ( QString );
@@ -124,22 +127,15 @@ class DialogFiles : public uiDialogFiles
     QString  qsPathName;
     bool     bReadable;
   };
-  class VFSelectItem : public QListBoxText  { //QListBoxItem {
-  public:
-    VFSelectItem ( bool, QListBox *, const QString &t=QString::null );
-    virtual void paint ( QPainter * );
-    virtual int height ( const QListBox * ) const;
 
-    bool bAlternate;
-  };
   class ThumbnailRequest : public ExecuteJob {
   public:
     ThumbnailRequest ( DialogFiles * );
     ThumbnailRequest ( DialogFiles *, QIconViewItem *, QString, uint );
     virtual ~ThumbnailRequest ( );
-	  
+
     virtual bool response ( );
-    
+
     QIconViewItem *pOwnerItem; 
     DialogFiles   *pParent;
     uint           iNumberOfThumbs;
@@ -148,9 +144,9 @@ class DialogFiles : public uiDialogFiles
   public:
     MultiThumbRequest ( DialogFiles *, QIconViewItem *, QString, QImage *, uint );
     virtual ~MultiThumbRequest ( );
-	  
+
     virtual bool response ( );
-    
+
     void createThumbs     ( );
     long iMovieLength;
     long iDelta;
@@ -164,7 +160,7 @@ class DialogFiles : public uiDialogFiles
   public:
     WorkWaiting ( QIconViewItem *, QImage *, bool );
     ~WorkWaiting ( );
-    
+
     QIconViewItem *pItem;
     QImage        *pImage;
     bool           bMarkIcon;
@@ -184,8 +180,18 @@ class DialogFiles : public uiDialogFiles
     SourceFileInfo *pSourceFileInfo; // only set if the item is created through a drop from a GroupView.
   };
 
+public:
+  class VFSelectItem : public QListBoxText  { //QListBoxItem {
+  public:
+    VFSelectItem ( bool, QListBox *, const QString &t=QString::null );
+    virtual void paint ( QPainter * );
+    virtual int height ( const QListBox * ) const;
+
+    bool bAlternate;
+  };
+
 public: // public strctures ...
-  DialogFiles ( SourceToolBar *, const char *n=0, WFlags f=0 );
+  DialogFiles ( QWidget *, const char *n=0, WFlags f=0 );
   virtual ~DialogFiles ( );
 
   void initWork      ( QIconViewItem *, QImage *, bool );
@@ -197,8 +203,8 @@ public: // public strctures ...
   QValueList<SourceFileEntry *> &getGroups ( );
 
 protected:
-  void initMe            ( SourceToolBar   * );
-  void initGroups        ( SourceToolBar   * );
+  void initMe            ( );
+  void initGroups        ( );
   void copyEntry         ( SourceFileEntry *, SourceFileEntry * );
   GroupView *addGroup    ( SourceFileEntry * );
   GroupView *addGroup    ( QString &, QStringList & );
@@ -223,7 +229,6 @@ protected:
   void setQuickDir       (     int );
   void setCurrentDir     ( QString );
   QString currentDir     ( );
-  void load              ( QStringList & );
 
   void setVirtualFolder  ( int );
   void toSourceGroup     ( int );
@@ -238,7 +243,12 @@ protected:
   void play              ( QString );
   void lock              ( );
   void unlock            ( );
-  virtual void timerEvent( QTimerEvent * );
+  QValueList<QListViewItem *> getSelectedVirtual ( );
+
+  // Virtual functions
+  virtual void timerEvent       ( QTimerEvent    * );
+  virtual void load      ( QStringList & );
+  virtual QString getDirFilter  ( );
 
 protected slots:
   virtual void slotToVirtualFolder       ( QListBoxItem  * );
@@ -247,12 +257,12 @@ protected slots:
   virtual void slotAllToSourceGroup      ( QListBoxItem  * );
   virtual void slotSourceToVirtualFolder ( QListBoxItem  * );
   virtual void slotSourceToSourceGroup   ( QListBoxItem  * );
-  virtual void slotVirtualChanged        ( QListViewItem * );
   virtual void slotDirectoryChanged      ( QListViewItem * );
   virtual void slotGroupContextMenu      ( QListViewItem *, const QPoint &, int );
   virtual void slotPreviewClicked        ( int, QIconViewItem *, const QPoint & );
   virtual void slotPreviewPressed        (      QIconViewItem *, const QPoint & );
   virtual void slotDroppedOnPreview      ( QDropEvent *, const QValueList<QIconDragItem> & );
+  virtual void slotVirtualChanged        ( );
   virtual void slotIconSelectionChanged  ( );
   virtual void slotAutoOpen              ( );
   virtual void slotQuickDir              ( );
@@ -279,7 +289,7 @@ protected slots:
   virtual void slotShowVirtual           ( QListViewItem *, const QPoint &, int );
   virtual void slotVirtualContextMenu    ( QListViewItem *, const QPoint &, int );
 
-private:
+protected:
   static bool m_bStars;
   static bool m_bName;
   static bool m_bDate;
