@@ -1685,27 +1685,31 @@ void DialogMovie::slotDelChapters ()
 
 void DialogMovie::slotCurrentChanged (QListBoxItem *pItem)
 {
-	uint t, iCount;
-	iCount = 0;
-	// we first count the number of selected chapters
-	for (t=0;t<m_pListBoxChapters->count();t++)	{
-		if (m_pListBoxChapters->isSelected (t))
-			iCount ++;
-	}
-	if (iCount != 1)
-		return;
-	// Last we jump to the position
-	if (m_pListBoxChapters->isSelected (pItem))	{
-		int iChapter = 0;
-		QTime chapterTime, zeroTime;
-		QString qsChapter = m_pListBoxChapters->currentText ();
-	
-		chapterTime = QTime::fromString (qsChapter);
-		iChapter = zeroTime.secsTo (chapterTime);
-		m_pMediaInterface->setPositionByTime (iChapter);
-//		if (!m_pMediaInterface->isPaused   ())
-//			m_pMediaInterface->pause   ();
-	}
+  uint t, iCount;
+  iCount = 0;
+  // we first count the number of selected chapters
+  for  ( t=0; t<m_pListBoxChapters->count ( ); t++ )  {
+    if ( m_pListBoxChapters->isSelected  ( t ) )
+      iCount ++;
+  }
+  if ( iCount != 1 )
+    return;
+  // Last we jump to the position
+  if ( m_pListBoxChapters->isSelected ( pItem ) )  {
+    int iChapter = 0;
+    QTime chapterTime, zeroTime;
+    QString qsChapter = m_pListBoxChapters->currentText ();
+    
+    chapterTime = QTime::fromString  (   qsChapter );
+    iChapter = zeroTime.secsTo       ( chapterTime );
+    m_pMediaInterface->setPositionByTime ( iChapter );
+    if ( ! m_pMediaInterface->isPlaying  ( ) )
+      slotPlay ( );
+
+    m_pMediaInterface->setPositionByTime ( iChapter );
+    if ( m_pMediaInterface->isPlaying    ( ) )
+      slotPlay ( );
+  }
 }
 
 void DialogMovie::slotTranscode ()
@@ -1762,6 +1766,7 @@ void DialogMovie::slotHeight()
 void DialogMovie::slotPlay  ()
 {
 	if (m_pMediaInterface)	{
+		bool bEnable = true;
 		if      (m_pMediaInterface->isPaused ())
 			 m_pMediaInterface->play ();
 		else if (m_pMediaInterface->isPlaying())
@@ -1769,10 +1774,15 @@ void DialogMovie::slotPlay  ()
 		else
 			m_pMediaInterface->playMRL(m_qsFileName);
 	
-		if (m_pMediaInterface->isPaused ())
+		if ( m_pMediaInterface->isPaused ( ) )  {
 			m_pButtonPlay->setText (tr("Play"));
+			bEnable = false;
+		}
 		else
 			m_pButtonPlay->setText (tr("Pause"));
+	
+		m_pButtonStart->setEnabled ( bEnable );
+		m_pButtonEnd  ->setEnabled ( bEnable );
 	}
 }
 
@@ -1786,7 +1796,9 @@ void DialogMovie::slotStop  ()
 		// The button should display "Play" now
 		m_pButtonPlay->setText (tr("Play"));
 		// and then logically we should put the screen to the beginnning.
-		m_pMediaInterface->getScreenshot ();
+		m_pMediaInterface->getScreenshot ( );
+		m_pButtonStart->setEnabled ( false );
+		m_pButtonEnd  ->setEnabled ( false );
 	}
 }
 
@@ -1874,15 +1886,16 @@ void DialogMovie::slotSliderValues (float fStart, float fEnd)
   QTime startTime;
   QTime endTime;
   QString qsFormat ("hh:mm:ss.zzz");
-  startTime = startTime.addMSecs ((int)(fStart * m_iMovieLength));
-  endTime = endTime.addMSecs ((int)(fEnd   * m_iMovieLength));
-  m_pEditStarting1->setText (startTime.toString (qsFormat));
-  m_pEditEnding1  ->setText (endTime.toString   (qsFormat));
+  startTime = startTime.addMSecs ( (int)(fStart * m_iMovieLength ) );
+  endTime   = endTime.addMSecs   ( (int)(fEnd   * m_iMovieLength ) );
+  m_pEditAdd      ->setText ( startTime.toString ( qsFormat ) );
+  m_pEditStarting1->setText ( startTime.toString ( qsFormat ) );
+  m_pEditEnding1  ->setText ( endTime.toString   ( qsFormat ) );
 
   // For now we disable auto transcoding of only the start slider is moved ...
   //	if ( ( fStart > 0.0001 ) || ( fEnd < 0.9999) )	{
   if ( fEnd < 0.995 ){
-    if ( (m_pButtonTranscode) && ( ! transcodeEnabled ()) )
+    if ( ( m_pButtonTranscode ) && ( ! transcodeEnabled ( ) ) )
       slotTranscode ( );
   }
 }
