@@ -20,13 +20,14 @@
 #include "uidialogtextfont.h"
 
 class QPaintEvent;
+class TextObject;
 
 class DialogTextFont : public uiDialogTextFont
 {
 	Q_OBJECT
 public:
-	 DialogTextFont (QWidget * parent, const char * name = 0, WFlags f = 0 );
-	~DialogTextFont ();
+	 DialogTextFont ( QWidget * parent, TextObject *p=NULL );
+	~DialogTextFont ( );
 
 	void     setFont (const QFont & );
 	QFont   &getFont              ( );
