@@ -2071,7 +2071,7 @@ bool ExportTitleset::checkForPrePostCommands ( SourceFileEntry *pEntry, bool bIg
 
   uint iCount = pEntry->listFileInfos.count();
   SourceFileInfo *pInfo     = NULL;
-  PlayMultiple   *pMultiple = NULL;
+  //PlayMultiple   *pMultiple = NULL;
   for ( i=0; i<iCount; i++ ) {
     pInfo = pEntry->listFileInfos[i];
 
