@@ -19,7 +19,6 @@
 #include <qpainter.h>
 #include <qwmatrix.h>
 #include <qpixmap.h>
-#include <qimage.h>
 #include <qdom.h>
 
 #include "xml_dvd.h"
@@ -33,36 +32,33 @@
 #include "dialoganimation.h"
 #include "structuretoolbar.h"
 
-ImageObject::ImageObject (QWidget *pParent)
-	: MenuObject (pParent)
+ImageObject::ImageObject ( QWidget *pParent )
+	: MenuObject ( pParent )
 {
-  m_qsObjectType = QString (IMAGE_OBJECT);
+  m_qsObjectType = QString ( IMAGE_OBJECT );
 }
 
-ImageObject::~ImageObject ()
+ImageObject::~ImageObject ( )
 {
 }
 
-void ImageObject::setPixmap(QPixmap &thePixmap)
+void ImageObject::setImage ( QImage &theImage )
 {
-	// Note: the Pixmap could be rotated, thus the bounding Rect might
-	// be of different size than the width or height of the Pixmap.
-	m_pixmap = thePixmap;
+  m_image = theImage;
 }
 
-void ImageObject::setFile (QString fileName)
+void ImageObject::setFile ( QString fileName )
 {
-	QString qsExtractionPath;
-	QFileInfo fileInfo(fileName);
-	m_qsFileName = fileInfo.fileName();
-	setName(m_qsFileName);
+	QString   qsExtractionPath;
+	QFileInfo fileInfo ( fileName );
+	m_qsFileName = fileInfo.fileName ( );
+	setName ( m_qsFileName );
 	qsExtractionPath = fileInfo.baseName ( true );
-	setExtractionPath(qsExtractionPath);
+	setExtractionPath ( qsExtractionPath );
 	m_qsFileName = fileName;
-//	m_pixmap = QPixmap (fileName);
 }
 
-void ImageObject::setZoom (float fZoom)
+void ImageObject::setZoom ( float fZoom )
 {
   // For the purpose of this class the Zoom is alreaduy incorporated into m_pixmap ...
   m_imageManipulator.fZoom = fZoom;
@@ -96,12 +92,12 @@ QString &ImageObject::fileName()
 	return m_qsFileName;
 }
 
-QPixmap &ImageObject::pixmap ()
+QImage &ImageObject::image ( )
 {
-	return m_pixmap;
+  return m_image;
 }
 
-float ImageObject::zoom()
+float ImageObject::zoom ( )
 {
 	return m_imageManipulator.fZoom;
 }
@@ -112,13 +108,13 @@ void ImageObject::drawContents ( QPainter *painter )
 	QWMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
-	centerPos.setX (rect().x() + (int)((float)rect().width () / 2.0));
-	centerPos.setY (rect().y() + (int)((float)rect().height() / 2.0));
+	centerPos.setX ( rect ( ).x ( ) + (int)( (float)rect ( ).width  ( ) / 2.0 ) );
+	centerPos.setY ( rect ( ).y ( ) + (int)( (float)rect ( ).height ( ) / 2.0 ) );
 	// Here we define the cenetered rect.
-	QRect theRect ((int)-(rect().width()/ 2.0), (int)-(rect().height()/2.0), rect().width(), rect().height());
+	QRect theRect  ( (int)-( rect ( ).width ( )/ 2.0 ), (int)-( rect ( ).height ( ) / 2.0 ), rect ( ).width ( ), rect ( ).height ( ) );
 
-	QPen thePen (QColor (255,0,0), 2, Qt::DashDotLine);
-	painter->setPen(thePen);
+	QPen thePen ( QColor ( 255, 0, 0 ), 2, Qt::DashDotLine );
+	painter->setPen ( thePen );
 
 	// From the Qt documentation ...
 	// This transformation engine is a three-step pipeline
@@ -136,22 +132,22 @@ void ImageObject::drawContents ( QPainter *painter )
 	theMatrix.rotate ( manipulator ( ).fRotate );
 
 	// Here we get the rect that encompasses the button for this object.
-	m_boundingRect = theMatrix.mapRect(theRect);
+	m_boundingRect = theMatrix.mapRect ( theRect );
 
-	if (m_bDrawRect)
+	if ( m_bDrawRect )
 	  drawActiveFrame ( painter );
 
-	painter->setWorldMatrix(theMatrix);
+	painter->setWorldMatrix ( theMatrix );
 
 	// Here we re-set the world matrix and translate the newly drawn ... thing ...
-	if ( isActive () )
+	if ( isActive ( ) )
 	  painter->drawRect(theRect);
 	
-	theMatrix.reset();
-	painter->setWorldMatrix(theMatrix);
+	theMatrix.reset ( );
+	painter->setWorldMatrix ( theMatrix );
 	
 	// check if we have a complete transparency, in which case we don't even need to bother...
-	if (manipulator().fTransparency == 1.0)
+	if ( manipulator ( ).fTransparency == 1.0 )
 		return;
 
 	if (!m_bDrawRect)	{
@@ -160,31 +156,34 @@ void ImageObject::drawContents ( QPainter *painter )
 
 		int t, x, y;
 		QRgb thePixel;
-		int iSourceHeight = pixmap().height();
-		int iSourceWidth  = pixmap().width ();
+		int iSourceHeight = image ( ).height ( );
+		int iSourceWidth  = image ( ).width  ( );
 		int iSourceStartX = 0;
 		int iSourceStartY = 0;
-		int iTargetStartX = painter->viewport().x() + m_boundingRect.x();
-		int iTargetStartY = painter->viewport().y() + m_boundingRect.y();
+		int iTargetStartX = painter->viewport ( ).x ( ) + m_boundingRect.x ( );
+		int iTargetStartY = painter->viewport ( ).y ( ) + m_boundingRect.y ( );
 		// Use the fast method whenever possible
-		if (	(manipulator().fRotate       == 0.0) && 
-			(manipulator().fShearX       == 0.0) && 
-			(manipulator().fShearY       == 0.0) &&
-			(manipulator().fTransparency == 0.0) && 
-			(manipulator().listColorKeys.count() < 1) )
-			bitBlt (painter->device(), iTargetStartX, iTargetStartY, &pixmap(), iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+		if (	( manipulator ( ).fRotate        == 0.0 ) && 
+			( manipulator ( ).fShearX        == 0.0 ) && 
+			( manipulator ( ).fShearY        == 0.0 ) &&
+			( manipulator ( ).fTransparency  == 0.0 ) && 
+			( manipulator ( ).listColorKeys.count ( ) < 1 ) ) {
+		  //bitBlt ( painter->device ( ), iTargetStartX, iTargetStartY, &pixmap(), iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
+		  painter->drawImage ( iTargetStartX, iTargetStartY, image ( ), iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP );
+		}
+		//iSourceStartX, iSourceStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
 		// Okay if we can not use bitBlt we have to go through the exact calculations ...
 		else	{
 			// First we need to create a Pixmap which holds the Target pixels
-			QImage theImage = pixmap().convertToImage();
+			QImage theImage = image ( );
 			QColor sourceColor, targetColor, theColor;
-			QRgb sourcePixel;
+			QRgb   sourcePixel;
 			QImage sourceImg;
-			float fTargetTrans, fSourceTrans;
-			fTargetTrans = 1.0 - manipulator().fTransparency;
-			fSourceTrans = manipulator().fTransparency;
-			if (fTargetTrans != 0.0)	{
-				QPixmap sourcePix (iSourceWidth, iSourceHeight);
+			float  fTargetTrans, fSourceTrans;
+			fTargetTrans = 1.0 - manipulator ( ).fTransparency;
+			fSourceTrans =       manipulator ( ).fTransparency;
+			if ( fTargetTrans != 0.0 )	{
+				QPixmap sourcePix ( iSourceWidth, iSourceHeight );
 				bitBlt (&sourcePix, 0, 0, painter->device(), iTargetStartX, iTargetStartY, iSourceWidth, iSourceHeight, Qt::CopyROP, true);
 				// To get Pixel information we need a QImage however ...
 				sourceImg = sourcePix.convertToImage();
@@ -311,21 +310,23 @@ void ImageObject::updatePixmap()
 
 	// In order to speed up the whole procedure, we set the matrix first to scale the image,
 	// then we handle the color functions on the smaller image and lastly we apply the rotation,shearing...
-	int iRed, iGreen, iBlue;
-	int x, y;
-	bool bLighter = true;
-	float fAdjust = 0.0;
+	int    iRed, iGreen, iBlue, iAlpha;
+	int    x, y;
+	int    iLighter = 0;
+	float  fAdjust  = 0.0;
 	QColor theColor;
-	QRgb thePix;	// QRgb defined as :  0xAARRGGBB;
+	QRgb   thePix;	// QRgb defined as :  0xAARRGGBB;
+	Rgba   rgba;
 	QWMatrix theMatrix;
 	// Here we calculate the center point of gravity (rotation)
 	QPoint centerPos;
 
-	if (fileName().isEmpty())
+	if ( fileName ( ).isEmpty ( ) )
 		return;
 
-	QImage theImage(fileName());
-	if (theImage.isNull())
+	QImage theImage ( fileName ( ) );
+
+	if ( theImage.isNull ( ) )
 		return;
 
 	// the kenBurns is taken care of here ...
@@ -381,43 +382,56 @@ void ImageObject::updatePixmap()
 
 	// Here we create the scaled image ...
 	theImage = theImage.xForm ( theMatrix );
-
 	// create empty image.
 	QImage imageColored = QImage (theImage.width(), theImage.height(), theImage.depth());
-	if (manipulator().fBrightness > 0.0)	{
-		bLighter = true;
-		fAdjust = 100 + manipulator().fBrightness * 300;
-	}
-	else	{
-		bLighter = false;
-		fAdjust = 100 + manipulator().fBrightness * -300;
-	}
-	for (y=0;y<theImage.height();y++)	{
-		for (x=0;x<theImage.width();x++)	{
-			thePix = theImage.pixel ( x, y );
-			iRed   = (int)((float)qRed  (thePix) * manipulator ( ).fRed   );
-			iBlue  = (int)((float)qBlue (thePix) * manipulator ( ).fBlue  );
-			iGreen = (int)((float)qGreen(thePix) * manipulator ( ).fGreen );
-
-			theColor = QColor (iRed, iGreen, iBlue);
-			if (bLighter)
-				theColor = theColor.light ( (int)fAdjust );
-			else
-				theColor = theColor.dark  ( (int)fAdjust );
-			// This test is to mask out the transparency color (0, 0, 0)
-			if (theColor == QColor (0,0,0))
-				theColor = QColor (0,0,1);
-			imageColored.setPixel (x, y, theColor.rgb());
-		}
+	imageColored.setAlphaBuffer ( true );
+	if ( ( manipulator ( ).fBrightness != 0.0 ) ||
+	     ( manipulator ( ).fRed        != 1.0 ) ||
+	     ( manipulator ( ).fGreen      != 1.0 ) ||
+	     ( manipulator ( ).fBlue       != 1.0 ) ) {
+	  if ( manipulator ( ).fBrightness > 0.0 )	{
+	    iLighter = 1;
+	    fAdjust = 100 + manipulator ( ).fBrightness * 300;
+	  }
+	  else	{
+	    iLighter = -1;
+	    fAdjust  = 100 + manipulator ( ).fBrightness * -300;
+	  }
+	  for (y=0;y<theImage.height();y++)	{
+	    for (x=0;x<theImage.width();x++)	{
+	      thePix = theImage.pixel ( x, y );
+	      iRed   = (int)((float)qRed  (thePix) * manipulator ( ).fRed   );
+	      iBlue  = (int)((float)qBlue (thePix) * manipulator ( ).fBlue  );
+	      iGreen = (int)((float)qGreen(thePix) * manipulator ( ).fGreen );
+	      iAlpha = qAlpha ( thePix );
+	      
+	      theColor =  QColor ( iRed, iGreen, iBlue );
+	      if ( iLighter != 0 ) {
+		if ( iLighter == 1 )
+		  theColor = theColor.light ( (int)fAdjust );
+		else 
+		  theColor = theColor.dark  ( (int)fAdjust );
+	      }
+	      // This test is to mask out the transparency color (0, 0, 0)
+	      if ( theColor == QColor ( 0, 0, 0 ) )
+		rgba      = QColor ( 0, 0, 1 );
+	      else {
+		rgba.setRgb   ( theColor.rgb ( ) );
+		rgba.setAlpha ( iAlpha );
+	      }
+	      imageColored.setPixel ( x, y, rgba.rgb ( ) );
+	    }
+	  }
 	}
+	else
+	  imageColored = theImage;
 	// Next we re-set the matrix ...
 	theMatrix.reset ();
 	// and plug in the remaining operations ...
-	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	theMatrix.rotate (manipulator().fRotate);
-	theImage = imageColored.xForm( theMatrix );
-	m_pixmap.convertFromImage(theImage);
-	emit (signalUpdatePixmap());
+	theMatrix.shear  ( manipulator ( ).fShearX, manipulator ( ).fShearY );
+	theMatrix.rotate ( manipulator ( ).fRotate );
+	m_image = imageColored.xForm   ( theMatrix );
+	emit ( signalUpdatePixmap ( ) );
 }
 
 bool ImageObject::readProjectFile  (QDomNode &theNode)
@@ -694,15 +708,15 @@ void ImageObject::slotRotate270()
 
 void ImageObject::rotate(float fRot)
 {
-	QWMatrix theMatrix;
-	theMatrix.rotate (fRot);
-	float fRotate = manipulator().fRotate + fRot;
-	if (fRotate > 180.0)
-		fRotate -= 360.0;
-	manipulator().fRotate = fRotate;
-	m_pixmap = m_pixmap.xForm( theMatrix );
-	emit (signalUpdatePixmap());
-	parent()->update();
+  QWMatrix theMatrix;
+  theMatrix.rotate ( fRot );
+  float fRotate = manipulator ( ).fRotate + fRot;
+  if ( fRotate  > 180.0 )
+       fRotate -= 360.0;
+  manipulator ( ).fRotate = fRotate;
+  m_image  = m_image.xForm    ( theMatrix );
+  emit   ( signalUpdatePixmap ( ) );
+  parent ( )->update ( );
 }
 
 void ImageObject::slotMatrix()
@@ -733,11 +747,11 @@ void ImageObject::slotDefineAsButton ( )
 MenuObject *ImageObject::clone ( QWidget *pParent, MenuObject * )
 {
   if ( !pParent )
-    pParent = MenuObject::parent ( );
+    pParent = MenuObject::parent  ( );
   ImageObject *pNewObject = new ImageObject ( pParent );
-  pNewObject->setPixmap ( pixmap   ( ) );
-  pNewObject->setFile   ( fileName ( ) );
-  pNewObject->setZoom   ( zoom     ( ) );
+  pNewObject->setImage ( image    ( ) );
+  pNewObject->setFile  ( fileName ( ) );
+  pNewObject->setZoom  ( zoom     ( ) );
   // The following two are not really needed, since we get those
   // informations solely from the Normal State - objects ...
   pNewObject->setRect        ( rect        ( ) );
