@@ -628,24 +628,21 @@ ImageObject *DVDAuthor::getButtonImageFromLayer ( DVDMenu *pMenu, QRect &theRect
     return NULL;
   QString qsFileName;
   QImage  theImage ( qsImageName );
-  if ( theImage.width() < 10 )
+  if ( theImage.width ( )  <  10 )
     return NULL;
 
   Utils        theUtil;
   QImage       theButtonImage ( theRect.width(), theRect.height(), 8, 256); //, theImage.depth() );
-  QPixmap      thePixmap;
   ImageObject *pImage = new ImageObject ( pMenu->getMenuPreview () );
 
   bitBlt ( &theButtonImage, 0, 0, &theImage, theRect.x(), theRect.y(), theRect.width(), theRect.height(), Qt::CopyROP );
   qsFileName = theUtil.getUniqueTempFile(DRAGGED_IMAGE_NAME);
   theButtonImage.save (qsFileName, "PNG");
 
-  thePixmap.convertFromImage ( theButtonImage );
-
-  pImage->setZoom   ( 1.0f       );
-  pImage->setRect   ( theRect    );
-  pImage->setPixmap ( thePixmap  );
-  pImage->setFile   ( qsFileName );
+  pImage->setZoom  ( 1.0f           );
+  pImage->setRect  ( theRect        );
+  pImage->setImage ( theButtonImage );
+  pImage->setFile  ( qsFileName     );
 
   return pImage;
 }
