@@ -207,9 +207,11 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
   qsValue     = value ( TransKeys, TransEndingAt );
   iEndingAt   = qsValue.toLong ( );
   if ( iEndingAt < 20 )
-       iEndingAt = 1000000; // approx. 9.3 hours
+       iEndingAt = 1000000000; // approx. 9.3 hours
   if ( iStartingAt > iEndingAt )
        iStartingAt = 0;
+  iEndingAt   = (long)( iEndingAt   / 1000.0 ); // convert from msec to seconds
+  iStartingAt = (long)( iStartingAt / 1000.0 ); // convert form msec to seconds
   setValue ( TransKeys, TransStartingAt, QString ( "%1" ).arg ( iStartingAt ) );
   setValue ( TransKeys, TransEndingAt,   QString ( "%1" ).arg ( iEndingAt   ) );
 
