@@ -21,10 +21,11 @@
 #include <qfileinfo.h>
 #include <qlistview.h>
 #include <qpainter.h>
-#include <qpixmap.h>
 #include <qimage.h>
+#include <qtimer.h>
 
 #include "global.h"
+#include "qdvdauthor.h"
 #include "messagebox.h"
 #include "sourcefileentry.h"
 #include "listviewitemmedia.h"
@@ -47,23 +48,26 @@ ListViewItemMedia::ListViewItemMedia (QListView *pListView, QListViewItem *pAfte
 	initMe (pEntry, theColor);
 }
 
-ListViewItemMedia::ListViewItemMedia (QListViewItem *pListViewItem, SourceFileInfo *pInfo, const QColor &color, QString t1, QString t2, QString t3)
-	: QListViewItem (pListViewItem, t1, t2, t3)
+ListViewItemMedia::ListViewItemMedia ( QListViewItem *pListViewItem, SourceFileInfo *pInfo, const QColor &color, QString str, QSize size )
+  : QListViewItem ( pListViewItem, QString ( ), str )
 {
-	m_iButtonState     = StateStop;
-	m_backgroundColor  = color;
-	m_pSourceFileEntry = NULL;
-	m_pSourceFileInfo  = pInfo;
+  m_iButtonState     = StateStop;
+  m_backgroundColor  = color;
+  m_pSourceFileEntry = NULL;
+  m_pSourceFileInfo  = pInfo;
+  m_pAnimateMini     = NULL;
+  m_sizeThumbnails   = size;
 }
 
 ListViewItemMedia::~ListViewItemMedia ()
 {
+  if ( m_pAnimateMini )
+    delete m_pAnimateMini;
+  m_pAnimateMini = NULL;
 }
 
-void ListViewItemMedia::initMe (SourceFileEntry *pEntry, const QColor &theBaseColor)
+void ListViewItemMedia::initMe ( SourceFileEntry *pEntry, const QColor &theBaseColor )
 {
-  if ( ! pEntry )
-	  return;
   // Here we create the sub items according to the SourceFileEntry -> listFileInfos
   int t;
   QColor              theColor;
@@ -74,11 +78,19 @@ void ListViewItemMedia::initMe (SourceFileEntry *pEntry, const QColor &theBaseCo
   m_pSourceFileInfo  = NULL;
   m_iButtonState     = StateStop;
   m_iPreviousButtonState = 1000;
-  
+  m_pAnimateMini     = NULL;
+  m_sizeThumbnails   = QSize ( 50, 50 );
+
   sortChildItems (-1, false);
   setOpen (true);
   setDragEnabled (true);
   setDropEnabled (true);
+
+  if ( ! pEntry )
+	  return;
+
+  m_sizeThumbnails = pEntry->sizeThumbnail;
+
   for(t=pEntry->listFileInfos.count()-1;t>=0;t--)	{
     pInfo = pEntry->listFileInfos[t];
     if ( ! pInfo )
@@ -90,7 +102,7 @@ void ListViewItemMedia::initMe (SourceFileEntry *pEntry, const QColor &theBaseCo
     fileInfo.setFile ( pInfo->qsFileName );
     
     QString qsInfo (fileInfo.fileName () + QString ("\n") + pInfo->qsLength);
-    ListViewItemMedia *pItem = new ListViewItemMedia (this, pInfo, theColor, QString(), qsInfo, QString());
+    ListViewItemMedia *pItem = new ListViewItemMedia ( this, pInfo, theColor, qsInfo, m_sizeThumbnails );
     pItem->setOpen (true);
     pItem->setDragEnabled (true);
     pItem->setDropEnabled (true);
@@ -161,43 +173,47 @@ void ListViewItemMedia::replaceInfo (SourceFileInfo *pInfo)
   }
 }
 
-QPixmap &ListViewItemMedia::attachButtons (QImage &theImage, QSize sizeThumbnail)
+void ListViewItemMedia::attachButtons ( QImage *pSourceImage, QPixmap *pTargetPix )
 {
-	static QPixmap thePixmap;
-	// This function will attach the buttons to the left side of the image.
-	// Play / Stop / Back
-	int iThirdHeight = (int)((float)sizeThumbnail.height() / 3.0);
-	int iOffset = iThirdHeight;
-	int iDeltaY = (int)((sizeThumbnail.height()-theImage.height()) / 2.0);
-	if ( (iDeltaY < 1) || (iDeltaY > sizeThumbnail.height()) )
-		iDeltaY = 0;
-	// Here we create the final imageExtension (empty QImage)
-	QImage finalImage (sizeThumbnail.width() + iOffset, sizeThumbnail.height(), theImage.depth());
-	finalImage.fill (0); // fill all black 
-	// Next we fill in the image
-	bitBlt ( &finalImage, iOffset, iDeltaY, (const QImage *)&theImage, 0, 0, theImage.width(), theImage.height(), Qt::CopyROP);
+   QImage tempImage;
+   tempImage  = pSourceImage->smoothScale ( m_sizeThumbnails, QImage::ScaleMin );
+  *pTargetPix = attachButtons ( tempImage,  m_sizeThumbnails );
+}
 
-	thePixmap.convertFromImage(finalImage);
-	// And then we draw the Buttons ...
-	drawButtonState(&thePixmap);
-	return thePixmap;
+QPixmap &ListViewItemMedia::attachButtons ( QImage &theImage, QSize sizeThumbnail )
+{
+  static QPixmap thePixmap;
+  // This function will attach the buttons to the left side of the image.
+  // Play / Stop / Back
+  int iThirdHeight = (int)( (float)sizeThumbnail.height ( ) / 3.0 );
+  int iOffset = iThirdHeight;
+  int iDeltaY = (int)( ( sizeThumbnail.height ( ) - theImage.height ( ) ) / 2.0 );
+  if ( ( iDeltaY < 1 ) || ( iDeltaY > sizeThumbnail.height ( ) ) )
+         iDeltaY = 0;
+  // Here we create the final imageExtension (empty QImage)
+  QImage finalImage ( sizeThumbnail.width ( ) + iOffset, sizeThumbnail.height ( ), theImage.depth ( ) );
+  finalImage.fill ( 0 ); // fill all black 
+  // Next we fill in the image
+  bitBlt ( &finalImage, iOffset, iDeltaY, (const QImage *)&theImage, 0, 0, theImage.width(), theImage.height(), Qt::CopyROP);
+  
+  thePixmap.convertFromImage ( finalImage );
+  // And then we draw the Buttons ...
+  drawButtonState ( &thePixmap );
+  return thePixmap;
 }
 
 void ListViewItemMedia::drawButtonState (QPixmap *pPixmap)
 {
 	if ( ! pPixmap )
 		return;
-	// For speed purposes: If nothing has changed, the state remains the same,
-	// then the pixmap does not need to get re-drawn ...
-	if (m_iPreviousButtonState == m_iButtonState)
-		return;
+
 	// This function will draw the buttons over the passed Pixmap
 	uint t;
 	bool bSelected;
 	QPixmap theButton;
 	QImage theImage;
-	char *arrayNormalButtonState [] = {"button_play.png",  "button_stop.png",  "button_back.png"};
-	char *arrayPressedButtonState[] = {"button_cplay.png", "button_cstop.png", "button_cback.png"};
+	char arrayNormalButtonState [][20] = {"button_play.png",  "button_stop.png",  "button_back.png"};
+	char arrayPressedButtonState[][20] = {"button_cplay.png", "button_cstop.png", "button_cback.png"};
 	int iThirdHeight = (int)((float)pPixmap->height() / 3.0);
 	int iOffset = iThirdHeight;
 
@@ -268,76 +284,176 @@ SourceFileInfo *ListViewItemMedia::sourceFileInfo ()
 
 void ListViewItemMedia::itemClicked(QPoint &thePoint)
 {
-	// Okay if the header is clicked, we simply return ...
-	if (!sourceFileInfo ())
-		return;
-	SourceFileEntry *pSourceFileEntry = sourceFileEntry();
-	if (!pSourceFileEntry)
-		pSourceFileEntry = ((ListViewItemMedia *)parent())->sourceFileEntry();
-	if (pSourceFileEntry->bSoundSource)
-		return;
-	// this function is called when the user clicks in the ListView.
-	// Here we check if it hit one of the buttons ...
-	QPoint p = listView()->mapFromGlobal (thePoint);
-	QRect rect = listView()->itemRect (this);
-	int iStartWidth  = listView()->treeStepSize() * 2;
-	int iThirdHeight = (int)((float)height() / 3.0);
-	// Play /Stop / Back is th order
-	if ( (p.x() > iStartWidth) && (p.x() < iStartWidth + iThirdHeight)  && (p.y() < rect.y() + rect.height()) )	{
-		if (p.y() > rect.y())
-			m_iButtonState = StatePlay;
-		if (p.y() > rect.y() + iThirdHeight)
-			m_iButtonState = StateStop;
-		if (p.y() > rect.y() + iThirdHeight * 2.0)
-			m_iButtonState = StateBack;
-	}
-	// Next is to see what the user wants to do.
-	if (m_iButtonState != m_iPreviousButtonState)	{
-		QFileInfo fileInfo (sourceFileInfo()->qsFileName);
-		QString qsState ("Play");
-		if (m_iButtonState == StateStop)
-			qsState = QString ("Stop");
-		else if (m_iButtonState == StateBack)
-			qsState = QString ("Back");
-		QString qsMessage;
-		qsMessage = QString("%1 %2 not yet implemented.").arg(qsState).arg(fileInfo.fileName());
-		MessageBox::warning (NULL, "Not implemented", qsMessage, QMessageBox::Ok, QMessageBox::NoButton);
-//		ListViewMedia *pListView = (ListViewMedia *)listView();
-	}
-	drawButtonState ((QPixmap *)pixmap(0));
-	listView()->triggerUpdate();
+  // Okay if the header is clicked, we simply return ...
+  if ( ! sourceFileInfo ( ) )
+    return;
+  SourceFileEntry  *pSourceFileEntry =  sourceFileEntry ( );
+  if ( ! pSourceFileEntry )
+       pSourceFileEntry = ( (ListViewItemMedia *)parent ( ) )->sourceFileEntry ( );
+  if ( pSourceFileEntry->bSoundSource )
+    return;
+  // this function is called when the user clicks in the ListView.
+  // Here we check if it hit one of the buttons ...
+  QPoint   p = listView ( )->mapFromGlobal ( thePoint );
+  QRect rect = listView ( )->itemRect ( this );
+  int iStartWidth  = listView ( )->treeStepSize ( ) * 2;
+  int iThirdHeight = (int)( (float)height ( ) / 3.0 );
+  // Play /Stop / Back is th order
+  if ( ( p.x ( ) > iStartWidth ) && 
+       ( p.x ( ) < iStartWidth + iThirdHeight ) && 
+       ( p.y ( ) < rect.y ( )  + rect.height ( ) ) )  {
+    if ( p.y ( ) > rect.y ( ) )
+      m_iButtonState = StatePlay;
+    if ( p.y ( ) > rect.y ( ) + iThirdHeight )
+      m_iButtonState = StateStop;
+    if ( p.y ( ) > rect.y ( ) + iThirdHeight * 2.0 )
+      m_iButtonState = StateBack;
+  }
+  // Next is to see what the user wants to do.
+  if ( m_iButtonState != m_iPreviousButtonState )
+    miniButton ( m_iButtonState, sourceFileInfo ( )->qsFileName );
+
+  if ( m_iButtonState == StateBack )
+       m_iButtonState  = StateStop;
+
+  drawButtonState ( (QPixmap *)pixmap ( 0 ) );
+  listView ( )->triggerUpdate ( );
 }
 
-/*
-// Here is how multithreading support works.
-	- Create QThread derived class
-	- Implement run()
-	- Generate screenshot of MediaStream in pListFileInfo->pPreview
-	- When update is available then call QTimerEvent of FRAME_AVAILABLE to get back to the main thread.
-	- in QTimer event handler, update the GUI pixmap.
-	- When no more frames avail, then send QTimerEvent of END_OF_MEDIA
-	- When user clicks on "Stop" kill QThread class after a Timeout of 30 sec. 
-	-> set m_bDestroyMe = true;
-	-> In Thread, before updating pSourceFileInfo->pPixmap , check for m_bDestroyMe
-		-> if found emit QTimerEvent of DESTRTOY_ME
-		-> exit run()
+void ListViewItemMedia::miniButton ( int iState, QString &qsFileName )
+{
+  if ( ! m_pAnimateMini ) {
+    Cache::Thumbs::Entry *pEntry = Global::pThumbsCache->find ( qsFileName );
+    if ( pEntry ) {
+      m_pAnimateMini = new AnimateMini ( this );
+      m_pAnimateMini->initMe ( pEntry );
+    }
+    else // No cache object available yet ...
+      return;
+  }
+  else
+    m_pAnimateMini->refreshButtonState ( );
 
-What is needed 
-o	pListViewEntry		- to update Preview
-o	ListViewItemMedia	- to update Pixmap of ListViewItem
-o	SourceToolBar		- to get MediaEngine
-o	QThreadClass communicates with QListViewMedia class where the QTimer events are handled.
-o	Also needed is a structure to allow for multiple playing of source files at the same time
-o	After clicking on [Back], have the Back state for 2 sec before switching to STOP state and starting the destruction of the MediaEngine
+  if ( iState  == StateStop )
+    m_pAnimateMini->stop  ( );
+  else if ( iState == StatePlay )
+    m_pAnimateMini->start ( );
+  else if ( iState == StateBack )
+    m_pAnimateMini->info ( );
+}
+
+void ListViewItemMedia::nextThumb ( )
+{
+
+}
+
+AnimateMini::AnimateMini ( ListViewItemMedia *pItem )
+{
+  m_pItem          = pItem;
+  m_arrayPix       = NULL;
+  m_iCurrentPix    = 0;
+  m_iNumberOfPix   = 0;
+  m_pTimerThumbing = new QTimer ( this );
+  connect ( m_pTimerThumbing, SIGNAL( timeout ( ) ), this, SLOT ( slotAnimate ( ) ) );
+}
+
+AnimateMini::~AnimateMini ( )
+{
+  stop  ( );
+  clear ( );
+  delete m_pTimerThumbing;
+}
+
+void AnimateMini::slotAnimate ( )
+{
+  if ( m_arrayPix ) {
+    m_iCurrentPix ++;
+    if ( m_iCurrentPix >= m_iNumberOfPix )
+         m_iCurrentPix  = 0;
+
+    m_pItem->setPixmap ( 0, *m_arrayPix[m_iCurrentPix] );
+  }
+}
+
+void AnimateMini::reset ( )
+{
+  m_iCurrentPix = 0;
+  m_pItem->setPixmap ( 0, m_pixmapOrig );
+}
+
+void AnimateMini::clear ( )
+{
+  int t;
+  if ( m_arrayPix ) {
+    for ( t=0; t<m_iNumberOfPix; t++ )
+      delete m_arrayPix[t];
+    delete []m_arrayPix;
+  }  
+}
+
+void AnimateMini::initMe ( Cache::Thumbs::Entry *pCache )
+{
+  uint t;
+  QImage tempImage;
+  const QPixmap *pPixmap = m_pItem->pixmap ( 0 );
+  if ( pPixmap )
+    m_pixmapOrig = *pPixmap;
+  else {
+    QImage error = QImage::fromMimeSource ( "error.jpg" );
+    error = error.smoothScale     ( 45,45 );
+    m_pixmapOrig.convertFromImage ( error );
+    pPixmap = &m_pixmapOrig;
+  }
+  
+  stop  ( );
+  clear ( );
+  
+  if ( ! pCache->arrayOfThumbs )
+         pCache->loadImages  ( );
+
+  m_iNumberOfPix = pCache->iNumberOfThumbs;
+  m_arrayPix = new QPixmap *[m_iNumberOfPix];
+  for ( t=0; t<(uint)m_iNumberOfPix; t++ ) {
+     m_arrayPix[t] = new QPixmap;
+     m_pItem->attachButtons ( pCache->arrayOfThumbs[t], m_arrayPix[t] );
+  }
+}
+
+void AnimateMini::refreshButtonState ( )
+{
+  int t;
+  for ( t=0; t<m_iNumberOfPix; t++ )
+    m_pItem->drawButtonState ( m_arrayPix[t] );
+}
+
+void AnimateMini::start ( )
+{
+  if ( ! m_pTimerThumbing->isActive ( ) )
+         m_pTimerThumbing->start ( 1500 );
+}
+
+void AnimateMini::stop ( )
+{
+  if ( m_pTimerThumbing->isActive ( ) )
+       m_pTimerThumbing->stop     ( );
+  reset ( );
+}
+
+void AnimateMini::info ( )
+{
+  if ( m_pTimerThumbing->isActive ( ) )
+       m_pTimerThumbing->stop     ( );
+
+  SourceFileInfo *pInfo = m_pItem->sourceFileInfo ( );
+  if ( ! pInfo ) {
+    SourceFileEntry *pEntry =  m_pItem->sourceFileEntry ( );
+    if ( ( ! pEntry ) || ( pEntry->listFileInfos.count ( ) < 1 ) )
+      return;
+    pInfo = pEntry->listFileInfos[0];
+  }
+
+  Global::pApp->editSourceFileInfo ( pInfo );
+}
 
-QThreadClass holds pointer to pSourceFileInfo->pPreview
-MediaEngine pointer of its own MediaEngine.
 
-TimerEvents : 
--	DESTROY_ME
--	STOP (same as DESTROY_ME)
--	END_OF_MEDIA
--	FRAME_AVAILABLE
--	BACK
-*/
 
