@@ -14,10 +14,45 @@
 #ifndef LISTVIEWITEMMEDIA_H
 #define LISTVIEWITEMMEDIA_H
 
+
+#include <qpixmap.h>
 #include <qlistview.h>
 
+#include "cachethumbs.h"
+
+class ListViewItemMedia;
 class SourceFileEntry;
 class SourceFileInfo;
+class QTimer;
+
+class AnimateMini : public QObject
+{
+  Q_OBJECT
+  // This class is coupled with the CacheThumbs class
+  // and will animate the thumbnail in the VideoList
+public:
+           AnimateMini ( ListViewItemMedia * );
+  virtual ~AnimateMini ( );
+  
+  void initMe ( Cache::Thumbs::Entry * );
+  void refreshButtonState ( );
+  void reset  ( );
+  void clear  ( );
+  void start  ( );
+  void stop   ( );
+  void info   ( );
+
+protected slots:
+  virtual void slotAnimate ( );
+
+private:
+  QTimer   *m_pTimerThumbing;
+  QPixmap **m_arrayPix;
+  QPixmap   m_pixmapOrig;
+  int       m_iNumberOfPix;
+  int       m_iCurrentPix;
+  ListViewItemMedia *m_pItem;
+};
 
 class ListViewItemMedia : public QListViewItem
 {
@@ -26,7 +61,7 @@ public:
 	ListViewItemMedia ( QListView     *, SourceFileEntry *, const QColor & );
 	ListViewItemMedia ( QListViewItem *, SourceFileEntry *, const QColor & );
 	ListViewItemMedia ( QListView     *, QListViewItem   *, SourceFileEntry *, const QColor & );
-	ListViewItemMedia ( QListViewItem *, SourceFileInfo  *, const QColor &, QString, QString, QString );
+	ListViewItemMedia ( QListViewItem *, SourceFileInfo  *, const QColor &, QString, QSize );
 	virtual ~ListViewItemMedia       ( );
 
 	SourceFileEntry *sourceFileEntry ( );
@@ -36,22 +71,27 @@ public:
 	QColor backgroundColor ( );
 	void   replaceInfo     ( SourceFileInfo * );
 	void   updateItem      ( );
-
-	void itemClicked       ( QPoint & );
+	void   nextThumb       ( );
+	void   itemClicked     ( QPoint & );
 
 private:
-	void initMe ( SourceFileEntry *, const QColor & );
+	void initMe ( SourceFileEntry *, const QColor & );	void attachButtons ( QImage *, QPixmap * );
 	QPixmap &attachButtons ( QImage &, QSize );
+	void miniButton        ( int,  QString & );
 	void drawButtonState   ( QPixmap * );
 
 private:
 	uint m_iButtonState;
 	uint m_iPreviousButtonState;
+	AnimateMini *m_pAnimateMini;
 
 	QColor m_backgroundColor;
+	QSize  m_sizeThumbnails;
 	// Only one of the two possible data is valid
 	SourceFileEntry *m_pSourceFileEntry;
 	SourceFileInfo  *m_pSourceFileInfo;
+	
+	friend class AnimateMini;
 };
 
 #endif // LISTVIEWITEMMEDIA_H
