@@ -1022,40 +1022,40 @@ MenuObject *MenuPreview::insertDraggedSourceInfo(QDropEvent *pDropEvent, QImage
 }
 
 // Here we insert a dragged image, which came from somewhere ...
-MenuObject *MenuPreview::insertDraggedImage (QDropEvent *pDropEvent, QImage &theImage)
+MenuObject *MenuPreview::insertDraggedImage ( QDropEvent *pDropEvent, QImage &theImage )
 {
-	QPixmap thePixmap;
+	QImage  theImage2;
 	QString qsFileName;
 	QRect   theRect;
-	int iWidth, iHeight;
-	Utils theUtil;
-	QPoint thePoint (pDropEvent->pos());
+	int     iWidth, iHeight;
+	Utils   theUtil;
+	QPoint  thePoint (pDropEvent->pos());
 
 	qsFileName = theUtil.getUniqueTempFile(DRAGGED_IMAGE_NAME);
-	theImage.save (qsFileName, "PNG");
+	theImage.save ( qsFileName, "PNG" );
 
-	iWidth  = theImage.width();
-	iHeight = theImage.height();
+	iWidth  = theImage.width  ( );
+	iHeight = theImage.height ( );
 	// Here we resize if neccesary ...
 	if(  (theImage.width() > 720) || (theImage.height() > 576) )	{
-		CResizeDialog *pResizeDialog = new CResizeDialog ();
-		pResizeDialog->setImage(&theImage);
-		pResizeDialog->exec ();
+		CResizeDialog *pResizeDialog = new CResizeDialog ( );
+		pResizeDialog->setImage ( &theImage );
+		pResizeDialog->exec ( );
 		iWidth  = pResizeDialog->m_pEditWidth ->text().toInt();
 		iHeight = pResizeDialog->m_pEditHeight->text().toInt();
 //		iFormat = pResizeDialog->m_iFormat;
-		if (iWidth  < 1) iWidth  = 150;
-		if (iHeight < 1) iHeight = 150;
-		thePixmap = *pResizeDialog->m_pPixmapPreview->pixmap ();
+		if ( iWidth  < 1 ) iWidth  = 150;
+		if ( iHeight < 1 ) iHeight = 150;
+		theImage2 = pResizeDialog->m_pPixmapPreview->pixmap ( )->convertToImage ( );
 	}
 	else	// If not then we simply take the current Image ..
-		thePixmap.convertFromImage (theImage);
-	theRect   = QRect(thePoint.x(), thePoint.y(), iWidth, iHeight);
+		theImage2 = theImage;
+	theRect   = QRect ( thePoint.x ( ), thePoint.y ( ), iWidth, iHeight );
 	ImageObject *pImageObject = new ImageObject (this);
-	pImageObject->setZoom   (1.0f);
-	pImageObject->setRect   (theRect);
-	pImageObject->setPixmap (thePixmap);
-	pImageObject->setFile   (qsFileName);
+	pImageObject->setZoom  ( 1.0f       );
+	pImageObject->setRect  ( theRect    );
+	pImageObject->setImage ( theImage2  );
+	pImageObject->setFile  ( qsFileName );
 	m_pActiveObject = pImageObject;
 
 	// And last we connect the signals
@@ -1434,22 +1434,18 @@ MenuObject *MenuPreview::createImageObject(bool bShowDialog)
 	  fZoom = ((float)m_rectCurrentObject.width() / theImage.width());
 	  // Convert the image and generate the Pixmap
 	  theImage = theImage.smoothScale (iWidth, iHeight);	//, QImage::ScaleMin);
-	  QPixmap thePixmap;
-	  thePixmap.convertFromImage(theImage);
-	  // Clear memory ...
-	  theImage = QImage ();
 	  // And here we adopt the rect the user has drawn.
-	  m_rectCurrentObject.setHeight(iHeight);
+	  m_rectCurrentObject.setHeight ( iHeight );
 	  // Finally we create the ImageObject
-	  pImageObject = new ImageObject (this);
-	  pImageObject->setRect (m_rectCurrentObject);
-	  pImageObject->setZoom (fZoom);	// We want to say Zoom = 1.0 even if the original size is already zoomed.
-	  pImageObject->setFile(qsImageName);
-	  pImageObject->setPixmap(thePixmap);
+	  pImageObject = new ImageObject( this );
+	  pImageObject->setRect  ( m_rectCurrentObject );
+	  pImageObject->setZoom  ( fZoom       );  // We want to say Zoom = 1.0 even if the original size is already zoomed.
+	  pImageObject->setFile  ( qsImageName );
+	  pImageObject->setImage ( theImage    );
 
-	  m_listMenuObjects.append (pImageObject);
-	  emit (signalUpdateStructure());
-	  updatePixmap();
+	  m_listMenuObjects.append ( pImageObject );
+	  emit (signalUpdateStructure ( ) );
+	  updatePixmap ( );
 	}
 	else
 	  pImageObject = new ImageObject (this);
