@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Dec 14 12:09:08 2003
-**      by: Varol Okan using kate editor
+**   Created : Sun Dec 14 12:09:08 2003
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class generates the command line for dvdauthor.
 ** Current Version of DVDAUTHOR used is 0.67
@@ -21,6 +23,7 @@
 #include "buttonpreview.h"
 #include "menuobject.h"
 
+class QIconViewItem;
 class ButtonObject;
 class ImageObject;
 class TextObject;
@@ -37,12 +40,13 @@ class MenuPreview : public ButtonPreview
 	enum { StateUnknown=0, StateNormal, StateMoveSelected, StateReadyToCreate, StateCreating, StateSelecting, StateSelected };
 public:
 	// type of what has dropped on this MenuPreview
-	enum { DroppedDontKnow=0, DroppedImage, DroppedText, DroppedImageAndText, DroppedMovieAndText, DroppedPants};
+	enum { DroppedDontKnow=0, DroppedMovie, DroppedImage, DroppedText, DroppedImageAndText, DroppedMovieAndText, DroppedChapter, DroppedPants };
 	 
 	 MenuPreview ( QWidget * parent, const char * name = 0, WFlags f = 0 );
 	~MenuPreview ( );
-	void clear   ( QColor * );
-	void initMe  ( QColor * );
+	void clear   ( Rgba * );
+	void initMe  ( Rgba * );
+	MenuPreview &operator = ( MenuPreview & );
 
 	void respondSourceFiles ( QValueList<SourceFileEntry *> );
 	void respondSubMenus    ( QStringList );
@@ -59,6 +63,9 @@ public:
 	void setImageButton     ( bool );
 	void createAnimationData( QString &, long );
 
+	void          connectStdSlots ( MenuObject *, bool );
+	ButtonObject *defineAsButton  ( MenuObject *, bool b=true );
+
 	MenuObject *createFrameObject      ( bool b=true );
 	MenuObject *createTextObject       ( bool b=true );
 	MenuObject *createImageObject      ( bool b=true );
@@ -72,6 +79,7 @@ public slots:
 	virtual void slotAddImageObject        ( );
 	virtual void slotAddMovieObject        ( );
 	virtual void slotAddCollection         ( );
+	virtual void slotAddFromLibrary        ( );
 	virtual void slotUpdateStructure       ( );
 	virtual void slotUpdatePixmap          ( );
 	virtual void slotAddShadow             ( MenuObject   * );
@@ -83,8 +91,13 @@ public slots:
 	virtual void slotEmitDeleteMe          ( );
 	virtual void slotDeleteMenu            ( );
 	virtual void slotRenameMenu            ( );
+	virtual void slotCloneMenu             ( );
 	virtual void slotDestroyedButtonDialog ( );
 	virtual void slotEditTimeline          ( );
+	virtual void slotAlignSelection        ( );
+	virtual void slotConvertToPAL          ( );
+	virtual void slotConvertToNTSC         ( );
+	virtual void slotPaste                 ( );
 
 signals:
 	void signalUpdateStructure    ( );
@@ -93,8 +106,11 @@ signals:
 	void signalDeleteMe           ( );
 	void signalEditTimeline       ( );
 	void signalRenameMe           ( );
+	void signalCloneMe            ( );
+	void signalLibrary            ( );
+	void signalConvertMe          ( bool );
 	void signalDroppedSomething   ( uint );
-	void signalMaskColorChanged   ( QColor, QColor );
+	void signalMaskColorChanged   ( Rgba, Rgba );
 	void signalCreatedMovieObject ( MovieObject  *, bool );
 
 protected:
@@ -107,18 +123,23 @@ protected:
 	virtual void dropEvent      ( QDropEvent      * );
 	virtual void dragEnterEvent ( QDragEnterEvent * );
 
-//	virtual void drawContents (QPainter *);
 	QString &newButtonName ( );
 
 private:	// Private functions ...
 	MenuObject *insertDraggedObject     ( QDropEvent *, QImage  & );
 	MenuObject *insertDraggedImage      ( QDropEvent *, QImage  & );
 	MenuObject *insertDraggedMovie      ( QDropEvent *, QImage  &, long i=0 );
+	MenuObject *insertDraggedThumbnail  ( QDropEvent *, QImage  & );
+	MenuObject *insertDraggedChapter    ( QDropEvent *, QIconViewItem * );
+	void        insertDraggedChapters   ( QDropEvent *, QValueList<QIconViewItem *> & );
 	MenuObject *insertDraggedText       ( QDropEvent *, QString & );
 	MenuObject *insertDraggedSourceInfo ( QDropEvent *, QImage  & );// ButtonObject
 	MenuObject *insertDraggedSourceEntry( QDropEvent *, QImage  & );// FullScale Layouts and new menus and all the bells and whistles (In future release anyhow ...SORRY)
-	void        connectStdSlots         ( MenuObject * );
+	QString     getMovieFileName        ( MovieObject*, QStringList & );
 	void        checkSelection          ( );
+	QString     uniqueObjectName        ( QString, QString );
+	void        paste                   ( MenuObject * );
+	bool        isAnimationData         ( QString & );
 
 private:
 	QPixmap m_doubleBuffer;
@@ -128,7 +149,7 @@ private:
 	QRect   m_rectCurrentObject;
 	bool    m_bIsSubMenu;
 	bool    m_bIsMovieMenu;
-	QColor *m_pPgcColors;
+	Rgba   *m_pPgcColors;
 	DialogButton   *m_pDialogButton;
 	SelectionObject m_selectionObject;
 };
