@@ -1,4 +1,13 @@
-
+/****************************************************************************
+  ** Modifiers / ImageManpulator - classes
+  **
+  **   Created : 
+  **        by : Varol Okan using kate editor
+  ** Copyright : (c) Varol Okan
+  **   License : GPL v 2.0
+  **
+  **
+  ****************************************************************************/
 
 #ifndef MODIFIERS_H
 #define MODIFIERS_H
@@ -8,6 +17,8 @@
 #include <qvaluelist.h>
 
 class QListViewItem;
+class StructureItem;
+class StructureItem;
 
 class Modifiers
 {
@@ -18,6 +29,9 @@ public:
 	virtual bool writeProjectFile (QDomElement &);
 	virtual bool isUnchanged ();
 	Modifiers& operator = (Modifiers &);
+	StructureItem *createStructure ( StructureItem *, StructureItem * );
+
+
 	/** The rotation in degree [0.0 .. 360.0] */
 	double fRotate;
 	/** Zoom factor. 1.0 == noral size. */
@@ -36,6 +50,11 @@ public:
 	/** Here is the stop frameNo when the object should disapear in the menu. */
 	int    iStopFrame;
 	/** TODO: Later we can add some type of filter here, to have the object apear/disappear smoothly. */
+	
+protected:
+	// StructureItem to show the Modifiers in the StructureToolbar
+	StructureItem *m_pStructureItem;
+	friend class MenuObject;
 };
 
 class ImageManipulator : public Modifiers
@@ -49,10 +68,11 @@ public:
 			theColor    = pOrig->theColor;
 			fDeltaColor = pOrig->fDeltaColor;
 		}
-		colorKeying (QRgb clr, float fDelta)	{
+		colorKeying ( QRgb clr, float fDelta )  {
 			theColor    = clr;
 			fDeltaColor = fDelta;
 		}
+
 		/** The color to be filtered out */
 		QRgb theColor;
 		/** This will specify the delta in percent of the MAX value which should be used.
@@ -64,17 +84,21 @@ public:
 	};
 		 ImageManipulator ();
 	virtual ~ImageManipulator ();
-	virtual bool readProjectFile  (QDomNode &);
-	virtual bool writeProjectFile (QDomElement &);
-	virtual void createStructure  (QListViewItem *);
+	virtual bool readProjectFile  ( QDomNode &);
+	virtual bool writeProjectFile ( QDomElement &);
+	virtual StructureItem *createStructure ( StructureItem *, StructureItem *p=NULL );
 	virtual ImageManipulator& operator = (ImageManipulator &);
 	virtual bool isUnchanged ();
 	QString node_name;
 
 	QString backgroundFileName;
 	bool	bShowBackground;
-	float	fStartX;      // [0 .. 1]Which pixel to start drawing
-	float	fStartY;      // [0 .. 1]type float to be able to adopt different resolutions.
+	float	fStartX;          // [0 .. 1] Which pixel of the background to start at
+	float	fStartY;          // [0 .. 1] type float to be able to adopt different resolutions.
+	float	fKenBurnsX1;      // [0 .. 1] Which pixel of the image to start with
+	float	fKenBurnsY1;      // [0 .. 1] type float to be able to adopt different resolutions.
+	float	fKenBurnsX2;      // [0 .. 1] Which pixel of the image to start with
+	float	fKenBurnsY2;      // [0 .. 1] type float to be able to adopt different resolutions.
 	int	iTransformationMode;
 	float	fRed;         // [0.0 .. 1.0]
 	float	fGreen;       // [0.0 .. 1.0]
@@ -84,6 +108,8 @@ public:
 	int	iXRes;        // 720 Currently not used
 	int	iYRes;        // 480 currently not used
 	QValueList<colorKeying *> listColorKeys;
+
+	friend class ImageObject;
 };
 
 #endif // MODIFIERS_H
