@@ -180,30 +180,29 @@ QImage *MovieObject::previewImage ()
 	return &m_imagePreview;
 }
 
-void MovieObject::setPixmap(QPixmap &thePixmap)
+void MovieObject::setPixmap ( QPixmap &thePixmap )
 {
-	if (!thePixmap.isNull())	{
-		m_pixmap = thePixmap;
-		m_imagePreview = thePixmap.convertToImage ();
-		return;
-	}
-	// Here we set the temp image for now but in order to see it in the right size,
-	// we have to first stretch it to the movies original extensions 
-	// This is because once it is wrought through the manipulation and modifier 
-	// we have a zoomed stretched etc.. image.
-	//
-	// Note that the real imagePreview is generated in a background thread and later on passed into this object
-	// in order to have the GUI active.
-	QString qsFileName = fileName ();
-	m_imagePreview = QImage (QImage().fromMimeSource("please_wait.jpg"));
-	if ( (movieSize().width() > 5) && (movieSize().height() > 5) )
-		m_imagePreview = m_imagePreview.smoothScale (movieSize(), QImage::ScaleFree);
-	else
-		m_imagePreview = m_imagePreview.smoothScale (rect().size(), QImage::ScaleFree);
+  if ( ! thePixmap.isNull ( ) )  {
+    m_image        = thePixmap.convertToImage ( );
+    m_imagePreview = thePixmap.convertToImage ( );
+    return;
+  }
+  // Here we set the temp image for now but in order to see it in the right size,
+  // we have to first stretch it to the movies original extensions 
+  // This is because once it is wrought through the manipulation and modifier 
+  // we have a zoomed stretched etc.. image.
+  //
+  // Note that the real imagePreview is generated in a background thread and later on passed into this object
+  // in order to have the GUI active.
+  QString qsFileName = fileName ();
+  m_imagePreview = QImage (QImage().fromMimeSource("please_wait.jpg"));
+  if ( (movieSize().width() > 5) && (movieSize().height() > 5) )
+    m_imagePreview = m_imagePreview.smoothScale (movieSize(), QImage::ScaleFree);
+  else
+    m_imagePreview = m_imagePreview.smoothScale (rect().size(), QImage::ScaleFree);
 
-	updatePixmap (); 
-
-	MediaCreator::registerWithMediaScanner (this, qsFileName, &m_imagePreview, m_iMSecPreview );
+  updatePixmap (); 
+  MediaCreator::registerWithMediaScanner (this, qsFileName, &m_imagePreview, m_iMSecPreview );
 }
 
 void MovieObject::slotSetThumbnail ( long iMSecPreview )
@@ -297,9 +296,8 @@ void MovieObject::updatePixmap()
 	// and plug in the remaining operations ...
 	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	theImage = imageColored.xForm( theMatrix );
-	m_pixmap.convertFromImage(theImage);
-	emit (signalUpdatePixmap());
+	m_image = imageColored.xForm ( theMatrix );
+	emit    ( signalUpdatePixmap ( ) );
 }
 
 void MovieObject::slotEdit ()
@@ -402,13 +400,13 @@ void MovieObject::startConverting ( bool bAllowDialogs )
 	if (m_pDVDMenu)
 		qsMenuName = m_pDVDMenu->getInterface()->qsMenuName;
 
-	qsFullPath = QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( extractionPath ( ) );
-	qsCommand  = QString ("mkdir -p '%1'").arg (qsFullPath);
+	qsFullPath = QFile::encodeName ( QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( extractionPath ( ) ) );
+	qsCommand  = QString ( "mkdir -p '%1'" ).arg ( qsFullPath );
 	if ( system ((const char *)qsCommand) == -1 )
 		return;
 	// and now we check that the path has been created succesfully
-	theTempDir.setPath (qsFullPath);
-	if (!theTempDir.exists())	{
+	theTempDir.setPath ( QFile::decodeName ( qsFullPath.latin1 ( ) ) );
+	if ( ! theTempDir.exists ( ) )  {
 	  if ( bAllowDialogs )
 	    MessageBox::warning(NULL, tr("Could not create Path"), tr("Could not create Path \n%1").arg(qsFullPath), QMessageBox::Ok, QMessageBox::NoButton);
 	  return;
@@ -559,8 +557,8 @@ MenuObject *MovieObject::clone ( QWidget *pParent, MenuObject * )
 {
   if ( !pParent )
     pParent = MenuObject::parent ( );
-  MovieObject *pNewObject = new MovieObject ( pParent );
-  pNewObject->setPixmap      ( pixmap      ( ) );
+  MovieObject *pNewObject = new MovieObject( pParent );
+  pNewObject->setImage       ( image       ( ) );
   pNewObject->setFile        ( fileName    ( ) );
   pNewObject->setZoom        ( zoom        ( ) );
   pNewObject->setMSecPreview ( msecPreview ( ) );
@@ -657,8 +655,7 @@ void MovieObject::loadPixmap(QString qsFileName)
 	// and plug in the remaining operations ...
 	theMatrix.rotate (manipulator().fRotate);
 	theMatrix.shear  (manipulator().fShearX, manipulator().fShearY);
-	theImage = imageColored.xForm( theMatrix );
-	m_pixmap.convertFromImage(theImage);
+	m_image = imageColored.xForm( theMatrix );
 }
 
 void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int iTotalFramesToRender)
@@ -668,8 +665,6 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
 
   // Okay first step is get the fileName of the frame
   qsMenuName = dvdMenu()->getInterface()->qsMenuName;
-//	QFileInfo fileInfo (fileName());
-//	qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(fileInfo.fileName ());
   qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(extractionPath());
   QDir theDir (qsFullPath);
   theDir.setNameFilter ("0*.jpg");
