@@ -63,6 +63,7 @@ public:
 
 public slots:
 	virtual void fileNew      ( );
+	virtual void fileWizard   ( );
 	virtual void fileOpen     ( );
 	virtual void fileSave     ( );
 	virtual void fileSave     ( QString, bool b=false );
@@ -80,9 +81,12 @@ public slots:
 
 	virtual void polish                          ( );
 	virtual void slotAutosave                    ( );
-	virtual void slotPluginCallback ( int, QString, QString );
+	virtual void slotOneClickDVD                 ( );
 	virtual void slotActivatePlugin              ( );
 	virtual void slotActivatePlugin         (  int );
+	virtual void slotPluginCallback  ( int, QString, QString );
+	virtual void slotNewMenuResponse ( int, QString, QString );
+	virtual void slotNewSource       ( Plugin::SourceGroup * );
 	virtual void slotChangeLanguage         (  int );
 	virtual void slotVisibleRegion          ( bool );
 	virtual void slotSetup                       ( );
@@ -99,7 +103,6 @@ public slots:
 	virtual void slotAddFiles                    ( );
 	virtual void slotAddDirectory                ( );
 	virtual void slotAddFromTemplate             ( );
-	virtual void slotOneClickDVD                 ( );
 	virtual void slotFeedback                    ( );
 	virtual void slotTabChanged        ( QWidget * );
 	virtual void slotRemoveCurrentSubMenu        ( );
@@ -120,6 +123,7 @@ public slots:
 	virtual void slotConvert                     ( );
 	virtual void slotConvertCurrentMenu     ( bool );
 	virtual void slotAboutToShowMenu             ( );
+
 signals:
 	void signalVisibleRegion (bool);
 
@@ -183,7 +187,7 @@ private: 	// Private functions ...
 	void createMenuXml          ( );
 	void createDVD              ( );
 	bool checkHealth            ( );
-	QString getTempFile         (QString);
+	QString getTempFile         ( QString );
 
 private:
 	bool    m_bVisibleRegion;
@@ -216,6 +220,7 @@ private:
 
 	QToolBar *m_pToolbar;
 	QAction  *m_pActionToolbarNew;
+	QAction  *m_pActionToolbarWizard;
 	QAction  *m_pActionToolbarOpen;
 	QAction  *m_pActionToolbarSave;
 	QAction  *m_pActionToolbarSaveAs;
