@@ -1,6 +1,11 @@
 /****************************************************************************
 ** qdvdauthor.h file.
 **
+**   Created :
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ** This file handles some different graphics libraries.
 ** I generated it this way because I could not decide which
 ** library to go with. So I decided to leave it up to the user.
@@ -52,6 +57,7 @@ QImageHelper::~QImageHelper ()
 QStringList &QImageHelper::getAvailableResizeAlgorithms()
 {
 	static QStringList listAlgorithm;
+	listAlgorithm.clear ();
 	listAlgorithm << QT_RESIZE_ALGO;
 	return listAlgorithm;
 }
@@ -81,6 +87,8 @@ bool QImageHelper::dither (int iMaxColors, QColor *pPalette)
 		return true;
 	}
 	(QImage &)*this = KImageEffect::dither ((QImage &)*this, pPalette, iMaxColors);
+//	(QImage &)*this = KImageEffect::flatten((QImage &)*this, (const QColor &)pPalette[0], (const QColor &)pPalette[1], iMaxColors);
+
 	return true;
 }
 
