@@ -173,7 +173,7 @@ public:
 	void getScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHeight, double& scaleFactor) const;
 
 	/* get the xine engine, needed by the xine configuration dialog */
-	const xine_t* const getXineEngine() const;
+	const xine_t *getXineEngine ( ) const;
 	void saveXineConfig();
 
 	/* for fullscreen */
