@@ -34,7 +34,7 @@ QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlag
 	m_qsScreenshotName = QString (MPLAYER_TEMP_FILE);
 
 	m_bInPauseMode = false;
-	m_pMasterProcess = new QProcess;
+	m_pMasterProcess = new QProcess ( this );
 
 	m_rxParseElapsedTime = QRegExp ("V:(.*[0-9]) ");
 	m_rxParseElapsedTime.setMinimal(true);
@@ -50,15 +50,23 @@ QMPlayerWidget::QMPlayerWidget(QWidget *pParent, const char *pName, WFlags iFlag
 	QObject::connect (m_pMasterProcess, SIGNAL(processExited  ()), this, SLOT (slotProcessExited  ()));
 	QObject::connect (m_pMasterProcess, SIGNAL(wroteToStdin   ()), this, SLOT (slotWroteToStdin   ()));
 	QObject::connect (m_pMasterProcess, SIGNAL(launchFinished ()), this, SLOT (slotLaunchFinished ()));
+	QObject::connect (m_pMasterProcess, SIGNAL(destroyed      ()), m_pMasterProcess, SLOT (kill   ()));
 
 	// And finally load the initFile
 	loadInitFile();
 }
 
-QMPlayerWidget::~QMPlayerWidget()
+QMPlayerWidget::~QMPlayerWidget ( )
 {
-	if (m_pMasterProcess)
-		delete m_pMasterProcess;
+  if ( m_pMasterProcess ) {
+    if ( m_pMasterProcess->processIdentifier ( ) > 0 ) {
+      QString qsCommand = QString ( "kill -9 `ps -ef | grep -e mplayer -e %1 | awk '{print $2}'`" ).arg ( winId ( ) ); 
+      system ( qsCommand.ascii ( ) );
+    }
+    if ( m_pMasterProcess->isRunning ( ) )
+      m_pMasterProcess->kill   ( );
+    delete  m_pMasterProcess;
+  }
 }
 
 bool QMPlayerWidget::start(QStringList *pEnvironment)
@@ -96,6 +104,10 @@ bool QMPlayerWidget::start(QStringList *pEnvironment)
 
 	listCommand.append(QString("-identify"));
 	listCommand.append(QString("-framedrop"));
+
+	//listCommand.append ( ">/dev/null" );
+        //listCommand.append ( "2>&1" );
+
 	if ( m_qsFileName.find ( "dvd://" ) > -1 ) {
 	  QString qsTemp = m_qsFileName;
 	  qsTemp.remove ( "dvd:/" );
@@ -112,13 +124,15 @@ bool QMPlayerWidget::start(QStringList *pEnvironment)
 	  }
 	}
 	else {
-	  listCommand.append(QString ( "--" ) );
+	  listCommand.append ( QString ( "--" ) );
 	  listCommand.append ( m_qsFileName ); //QString("%1").arg(m_qsFileName));
 	}
+//	listCommand.append ( ">/dev/null" );
+//	listCommand.append ( "2>&1" );
 
 	// -ss 01:10:00 seeks to 1 hour 10 min
 	m_fLength = 0.0;
-	// printf ( "command < %s >\n", listCommand.join ( " " ).ascii ( ) );
+	//printf ( "<%p>command < %s >\n", m_pMasterProcess, listCommand.join ( " " ).ascii ( ) );
 
 	m_pMasterProcess->setArguments ( listCommand  );
 	emit (signalMPlayerStarted());
