@@ -2,8 +2,8 @@
                            videowindow.cpp 
                            -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.84 $
-    last modified        : $Date: 2007/04/06 04:03:18 $ by $Author: qdvdauthor $
+    revision             : $Revision: 1.86 $
+    last modified        : $Date: 2008/02/23 14:50:36 $ by $Author: qdvdauthor $
     copyright            : (C) 2003-2004 by J. Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -1993,7 +1993,7 @@ void QXineWidget::slotFakeKeyEvent()
 }
 
 
-const xine_t* const QXineWidget::GetXineEngine()const
+const xine_t *QXineWidget::GetXineEngine ( ) const
 {
   return xineEngine;
 }
