@@ -2,8 +2,8 @@
                            qxinewidget.h
                              -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.29 $
-    last modified        : $Date: 2004/03/21 10:16:43 $ by $Author: juergenk $
+    revision             : $Revision: 1.80 $
+    last modified        : $Date: 2008/02/23 14:50:36 $ by $Author: qdvdauthor $
     copyright            : (C) 2003-2004 by J. Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -88,7 +88,7 @@ public:
   void GetScreenshot(uchar*& rgb32BitData, int& videoWidth, int& videoHeight, double& scaleFactor);
 
  /* get the xine engine, needed by the xine configuration dialog */
-  const xine_t* const GetXineEngine() const;
+  const xine_t *GetXineEngine ( ) const;
 
   void StartMouseHideTimer();    /* for fullscreen */
   void StopMouseHideTimer();
