@@ -13,17 +13,18 @@
 
 CXmlSlideshow::CXmlSlideshow ()
 {
-	node_name = QString ("slideshow");
-	delay = -1;
-	filter_delay = -1;
-	xres = 720;
-	yres = 480;	// NTSC for now
-	ppArrayImg = NULL;
+	node_name     = QString ("slideshow");
+	delay         = -1;
+	filter_delay  = -1;
+	xres          = 720;
+	yres          = 480;	// NTSC for now
+	ppArrayImg    = NULL;
 	ppArrayFilter = NULL;
 }
+
 CXmlSlideshow::~CXmlSlideshow ()
 {
-	clear ();
+	clear ( );
 }
 
 void CXmlSlideshow::clear ()
@@ -32,15 +33,16 @@ void CXmlSlideshow::clear ()
 	uint t=0;
 	// The timObjectArray holds Img, and Filter objects, thus no need to delete these again.
 	time_object *pTimeObject;
-	for (t=0;t<m_listTimeObjects.count();t++)	{
-		 pTimeObject = m_listTimeObjects[t];
-			delete pTimeObject;
+	for ( t=0; t<m_listTimeObjects.count(); t++ )	{
+		pTimeObject = m_listTimeObjects[t];
+		delete pTimeObject;
 	}
+
 	if (ppArrayImg)
 		delete []ppArrayImg;
 	if (ppArrayFilter)
 		delete []ppArrayFilter;
-	ppArrayImg = NULL;
+	ppArrayImg    = NULL;
 	ppArrayFilter = NULL;
 	m_listTimeObjects.clear();
 	delay = -1;
@@ -324,6 +326,31 @@ CXmlSlideshow::img_struct *CXmlSlideshow::addImg()
 	return ppArrayImg[i];
 }
 
+void CXmlSlideshow::delImg ( CXmlSlideshow::img_struct *pImg )
+{
+  if ( ! ppArrayImg )
+    return;
+
+  m_listTimeObjects.remove ( pImg );
+
+  int t=0;
+  CXmlSlideshow::img_struct *pArray = ppArrayImg[0];
+  // First we find where the Img is ...
+  while ( pArray && ( pArray != pImg ) )
+    pArray = ppArrayImg[++t];
+
+  // Make sure we did not run through the whole array
+  if ( pImg == pArray ) {
+    // and shift all remaining entries one to the left
+    while ( pArray )  {
+      pArray = ppArrayImg[++t];
+      ppArrayImg[t-1] = pArray;
+    }
+    
+    delete pImg;
+  }
+}
+
 CXmlSlideshow::filter_struct *CXmlSlideshow::addFilter()
 {
 	// This function simply enlarges the array of available titlesets.
