@@ -23,7 +23,7 @@
 **
 ****************************************************************************/
 #include <stdlib.h>
-#ifdef QDVD_LINUX 
+#ifdef QDVD_LINUX
 #include <unistd.h>
 #endif
 
@@ -585,7 +585,7 @@ void SourceToolBar::slotAddMovie ( )
       }
       else if ( pInfo->qsStatus !=  QString ( "Ok" ) )
 	statusColor = QColor ( COLOR_MOVIE_FILES_BAD );
-      
+
       new QListViewItem ( m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
 			  pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
 			  pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName );
@@ -593,7 +593,7 @@ void SourceToolBar::slotAddMovie ( )
     new ListViewItemMedia ( m_pListViewAllSources, pEntry, statusColor );
     updateEntryHeader     ( pEntry );
   }
-  
+
   // Finally we should guesstimate the new size.
   Global::pApp->slotCalculateSize ( );
 }
@@ -629,7 +629,7 @@ void SourceToolBar::slotAddMovieOld ( )
       listAddMovies.remove  ( qsFileName );
     }
   }
-  
+
   addMovieList ( listAddMovies );
   addSound     ( listAddAudio  );
 }
@@ -675,7 +675,7 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
     pEntry->qsDisplayName += qsText;
   }
   else
-    pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)fileInfo.baseName(true));
+    pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)QFile::encodeName ( fileInfo.baseName ( true ) ) );
   m_listSourceFileEntries.append(pEntry);
   // Okay, now we should also add this into the list box ...
   addMovie (pEntry);
@@ -1108,7 +1108,7 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 void SourceToolBar::slotAddSlideshow()
 {
   Utils theUtil;
-  if ( ! m_pDVDAuthor->checkForNewProject ( ) )
+  if ( ! Global::pApp->checkForNewProject ( ) )
     return;
   // First we pop up the slideshow generation dialog box
   QString qsTempPath = theUtil.getTempFile(QString ());
