@@ -61,6 +61,7 @@ public:
 	SourceFileEntry *sourceFileEntry           ( uint );
 	SourceFileEntry *getCurrentSourceFileEntry ( );
 	SourceFileInfo  *getCurrentSourceFileInfo  ( );
+	void editSourceFileInfo                    ( SourceFileInfo  * );
 	void updateListViewItem                    ( SourceFileInfo  * );
 	bool checkRightAudioFormat                 ( SourceFileInfo  * );
 	bool checkRightFileFormat                  ( SourceFileInfo  * );
@@ -93,6 +94,7 @@ public slots:
 	virtual void slotEditAudio    ( );
 	virtual void slotDeleteSource ( );
 	virtual void slotTranscodeAll ( );
+	virtual void slotTranscodeNone( );
 	virtual void slotAllToTitleset( );
 	virtual void slotToNewSubmenu ( );
 	virtual void slotAddMovieOld  ( );
