@@ -638,7 +638,7 @@ QString TemplateDownload::findGuiSU ( )
   uint t;
   QString qsReturn;
   QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
-  char *arraySUs[3] = {"kdesu", "xsu", "gnomesu"};
+  char arraySUs[3][10] = {"kdesu", "xsu", "gnomesu"};
   QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
     // the next check is to see if we can find kdesu
