@@ -3,6 +3,11 @@
 **
 ** This file implements the TemplateWizardDialog.
 **
+**   Created :
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ** The following structure is assumed:
 ** /usr/share/qdvdauthor/template/static/<TemplateName>/<Files>
 ** /usr/share/qdvdauthor/template/animated/<TemplateName>/<Files>
@@ -28,23 +33,29 @@
 #include <qdir.h>
 #include <qtimer.h>
 #include <qcursor.h>
+#include <qregexp.h>
+#include <qlayout.h>
 #include <qlistbox.h>
 #include <qpainter.h>
 #include <qfileinfo.h>
 #include <qiconview.h>
 #include <qcombobox.h>
-//#include <qfiledialog.h>
+#include <qpushbutton.h>
 
 // Include the generated config files ...
 #include "CONFIG.h"
 #include "xml_dvd.h"
+#include "global.h"
 #include "utils.h"
 #include "qdvdauthor.h"
 #include "dvdmenu.h"
 #include "messagebox.h"
 #include "filepreviewdialog.h"
+#include "buttonobject.h"
+#include "movieobject.h"
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
+#include "qplayer/mediacreator.h"
 
 #include "sourcefileentry.h"
 #include "templatewizard.h"
@@ -106,12 +117,12 @@ void ListBoxToolTip::maybeTip(const QPoint& pos)
 
 TemplateWizard::DropZone::DropZone (int i, QString s, QRect r, QString qsType)
 {
-	bMovie  = false;
-	iNumber = i; 
-	iType   = IgnoreObject;
-	qsText  = s; 
-	rect    = r;
-	pPixmap = NULL;
+	bMovie       = false;
+	iNumber      = i; 
+	iType        = IgnoreObject;
+	qsText       = s; 
+	rect         = r;
+	pPixmap      = NULL;
 	if ( qsType == "ImageObject" )
 	  iType = ImageObject;
 	else if ( qsType == "MovieObject" )
@@ -134,7 +145,6 @@ TemplateWizard::TemplateWizard( QWidget* parent, const char* name, WFlags fl )
     : uiTemplateWizard( parent, name, fl )
 {
 	m_pDVDAuthor      = NULL;
-	m_pDVDMenu        = NULL;
 	m_fScale          = 0.0f;
 	m_bDontRestart    = false;
 	m_pListBoxToolTip = NULL;
@@ -215,8 +225,7 @@ void TemplateWizard::initMe (QDVDAuthor*pDVDAuthor)
 	connect (m_pIconViewAnimated,  SIGNAL( clicked (QIconViewItem *)), this, SLOT ( slotIconViewClicked (QIconViewItem *)));
 	connect (m_pIconViewTransition,SIGNAL( clicked (QIconViewItem *)), this, SLOT ( slotIconViewClicked (QIconViewItem *)));
 	connect (m_pButtonDetails,     SIGNAL( clicked ( ) ),              this, SLOT ( slotTemplateDetails ( ) ) );
-
-	connect (this,                 SIGNAL(helpClicked () ),           this, SLOT(slotHelp () ) );
+	connect (this,                 SIGNAL( helpClicked () ),           this, SLOT ( slotHelp () ) );
 }
 
 void TemplateWizard::slotPlaybackFinished ()
@@ -315,8 +324,13 @@ void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
 
   pIconView->clear ( );
   qsPrefixDir = QString ( "%1/.qdvdauthor/%2" ).arg ( qsHomeDir ).arg ( qsWhichTab );
-  for ( iTemplatePath=0;iTemplatePath<2;iTemplatePath++ ) {
-    
+  for (  iTemplatePath=0; iTemplatePath<2; iTemplatePath++ ) {
+    if ( iTemplatePath == 1 ) {
+      // for the second run we'll get the system wide installed Templates.
+      // Note: lcally installed Templates overrule System wide installed Templates.
+      qsPrefixDir = QString ("%1/share/qdvdauthor/%2").arg(PREFIX_DIRECTORY).arg(qsWhichTab);
+    }
+
     if ( ! theTemplates.exists (qsPrefixDir) ) {
       if ( iTemplatePath == 0 )
 	continue;
@@ -368,61 +382,9 @@ void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
       thePixmap = QPixmap (qsPixmap);
       new QIconViewItem (pIconView, qsTemplateName, thePixmap);
     }
-    // for the second run we'll get the system wide installed Templates.
-    // Note: lcally installed Templates overrule System wide installed Templates.
-    qsPrefixDir = QString ("%1/share/qdvdauthor/%2").arg(PREFIX_DIRECTORY).arg(qsWhichTab);
   }
 }
-/*
-void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
-{
-	uint t;
-	QStringList listTemplates;
-	QIconViewItem *pItem;
-	QString qsPrefixDir, qsPixmap, qsXMLFile, qsBackgroundFile;
-	QFileInfo fileInfo;
-	QPixmap thePixmap;
-	QDir theTemplates; 
-	QSize grid (50, 50);
-	qsPrefixDir = QString ("%1/share/qdvdauthor/%2").arg(PREFIX_DIRECTORY).arg(qsWhichTab);
 
-	pIconView->clear ( );
-	if ( ! theTemplates.exists (qsPrefixDir) )	{
-	  new QIconViewItem (pIconView, tr ("Warning no dir :\n%1").arg (qsPrefixDir));
-	  return;
-	}
-
-	pIconView->arrangeItemsInGrid (grid, TRUE);
-	
-	theTemplates.cd   (qsPrefixDir, TRUE);
-	listTemplates = theTemplates.entryList (QDir::Dirs, QDir::Name);
-	if (listTemplates.count () < 3)	{
-	  new QIconViewItem (pIconView, tr ("No %1 Backgrounds in dir :\n%2").arg(qsWhichTab).arg(qsPrefixDir));
-	  return;
-	}
-	for (t=0;t<listTemplates.count ();t++)	{
-		// Here we go through all directories and check if the preview is present.
-		// if so, then we snap the preview.jpg and create a ListItem
-		if ( (listTemplates[t] == ".") || (listTemplates[t] == ".") )
-			continue;
-		qsPixmap = QString ("%1/%2/%3").arg(qsPrefixDir).arg(listTemplates[t]).arg("thumbnail.png");
-		fileInfo.setFile (qsPixmap);
-		if ( ! fileInfo.exists() )
-			continue;
-		qsXMLFile = QString ("%1/%2/%3").arg(qsPrefixDir).arg(listTemplates[t]).arg("template.xml");
-		fileInfo.setFile (qsXMLFile);
-		if ( ! fileInfo.exists() )
-			continue;
-		qsBackgroundFile = QString ("%1/%2/background/background00000.jpg").arg(qsPrefixDir).arg(listTemplates[t]);
-		fileInfo.setFile (qsBackgroundFile);
-		if ( ! fileInfo.exists() )
-			continue;
-		thePixmap = QPixmap (qsPixmap);
-		new QIconViewItem (pIconView, listTemplates[t], thePixmap);
-	}
-	connect (pIconView, SIGNAL(clicked (QIconViewItem *)), this, SLOT(slotIconViewClicked (QIconViewItem *)));
-}
-*/
 void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
 {
   // The user clicked one of the Icons, 
@@ -512,7 +474,7 @@ void TemplateWizard::slotListBoxClicked (QListBoxItem *pItem)
 
 void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
 {
-  uint t, i;
+  uint t, i, iHeight;
   QImage  theImage;
   QString theText;
   QPoint  thePos;
@@ -535,13 +497,14 @@ void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
   }
   if ( ! pDropZone )
     return;
+  
   // Get the previewImage ...
   if (m_pDVDAuthor)	{
     for (t=0;(int)t<m_pDVDAuthor->sourceFileCount(); t++)	{
       pEntry = m_pDVDAuthor->sourceFileEntry ( t );
       for (i=0;i<pEntry->listFileInfos.count();i++)	{
 	if ( (pEntry)  &&  (theText.contains (pEntry->listFileInfos[i]->qsFileName) > 0 ) )	{
-	  pDropZone->qsFileName = pEntry->listFileInfos[i]->qsFileName;
+	  pDropZone->qsFileName   = pEntry->listFileInfos[i]->qsFileName;
 	  pInfo = pEntry->listFileInfos[i];
 	  // Exit both loops ...
 	  t = m_pDVDAuthor->sourceFileCount();
@@ -550,14 +513,28 @@ void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
       }
     }
   }
-  pDropZone->bMovie = true;
+  DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+  pDropZone->bMovie = pDND ? ( ! pDND->bImageButton ) : true;
+
   if ( ( pDropZone->iType != DropZone::TextObject ) && ( pDropZone->iType != DropZone::FrameObject ) )  {
-    if (pInfo && pInfo->pPreview)
-      theImage = pInfo->pPreview->smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
+    if (pInfo && pInfo->pPreview) {
+      float fRatio = (float)pInfo->pPreview->height ( ) / pInfo->pPreview->width ( );
+      // for the templates we want to use the width as our ruler (I.e. adjust the height of the image according to the ratio
+      iHeight = (int)(fRatio * pDropZone->rect.width ( ) );
+      theImage = pInfo->pPreview->smoothScale ((int)(m_fScale*pDropZone->rect.width ( ) ),(int)(m_fScale * iHeight), QImage::ScaleMin);
+      //theImage = pInfo->pPreview->smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
+    }
     else	{
       theImage = QImage().fromMimeSource( "error.jpg" );
-      theImage = theImage.smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
+      theImage = theImage.smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleFree );
     }
+    if ( ! pDropZone->bMovie ) {
+      Utils     theUtil;
+      QFileInfo fileInfo ( pDropZone->qsFileName );
+      pDropZone->qsFileName = theUtil.getTempFile ( fileInfo.baseName ( ) ) + QString (".png");
+      theImage.save ( pDropZone->qsFileName, "PNG", 100 );
+    }
+
     // Set the DropZoneValues ...
     // Note: theText is "$FileName : $size" so that does not work.
     // pDropZone->qsFileName = theText;
@@ -617,7 +594,8 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
   pDropZone->qsFileName = qsFileName;
   qsExtensions = pMediaInfo->getExtensions (true);
   if (qsExtensions.find ("."+backgroundInfo.extension(FALSE), 0, FALSE) > -1)	{
-    pDropZone->bMovie = true;
+    DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+    pDropZone->bMovie = pDND ? ( ! pDND->bImageButton ) : true;
     if ( ( pDropZone->iType == DropZone::TextObject ) || ( pDropZone->iType == DropZone::FrameObject ) ) {
       refreshBackground ( );
       return;
@@ -628,6 +606,8 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
     // The we save the screenshot in the temp dir
     qsFileName = theUtil.getTempFile(backgroundInfo.baseName())+QString (".png");
     theImage.save (qsFileName, "PNG");
+    if ( ! pDropZone->bMovie )
+           pDropZone->qsFileName = qsFileName;
   }
   else	// Not a movie file, then we should reset this ...
     theImage = QImage(qsFileName);
@@ -820,11 +800,6 @@ void TemplateWizard::refreshBackground ()
   m_pFrameProperties->setBackgroundPixmap  ( thePixmap );
 }
 
-DVDMenu *TemplateWizard::getMenu ()
-{
-	return m_pDVDMenu;
-}
-
 QString TemplateWizard::getSourceEntryName (QString qsFileName)
 {
   // This function will check if the file is already part of a SourceFileEntry.
@@ -850,7 +825,7 @@ QString TemplateWizard::getSourceEntryName (QString qsFileName)
 void TemplateWizard::slotHelp ()
 {
   QString qsHeader, qsHtml;
-  qsHeader = tr ("Wizard for templstes.");
+  qsHeader = tr ("Wizard for templates.");
 
   qsHtml  = tr ( "Select <B>One</B> of the templates you like to use and click on [<B>Next ></B>]<P>" );
   qsHtml += tr ( "Don't forget to define if you want to add a new menu or if you wnt to replace an existing menu. This can be done by the ComboBox on the right.<P>" );
@@ -863,12 +838,9 @@ void TemplateWizard::slotHelp ()
 
 void TemplateWizard::reject ()
 {
-	if (m_pDVDMenu)
-		delete m_pDVDMenu;
-	m_pDVDMenu = NULL;
 	QWizard::reject();
 }
-#include <qregexp.h>
+
 void TemplateWizard::accept ()
 {
 	// First we are going to replace the DropZone placeholder and then create a DVDMenu.
@@ -909,6 +881,8 @@ void TemplateWizard::accept ()
 		  qsSourceEntry = getSourceEntryName ( m_listDropZones[t]->qsFileName );
 		  if ( qsSourceEntry.isEmpty ( ) ) // If this movie is not yet in a SourceFileEntry, then use he newly created one.
 		       qsSourceEntry = qsEntryName;
+		  qsSourceEntry.replace ( "<", "&lt;" );
+		  qsSourceEntry.replace ( ">", "&gt;" );
 		  rx.setMinimal ( true );
 		  qsPattern = QString ( "DROP_ZONE_%1_BUTTON[^>]*>.*</.DROP_ZONE_%2_BUTTON.>" ).arg ( i ).arg ( i );		  
 		  rx.setPattern ( qsPattern );
@@ -920,6 +894,8 @@ void TemplateWizard::accept ()
 		    else // Could not find in template ... create on the spot.
 		      qsButtonXml.replace ( "Action=", "SourceEntry=\"" + qsSourceEntry + "\" Action=" );
 		  }
+		  // TODO: fix this function ...
+		  adjustPixmapHeight ( m_listDropZones[t]->pPixmap, qsButtonXml );
 
 		  m_qsXMLDVDMenu.replace ( rx, qsButtonXml );
 		} // end of replacing this buttonObjects DROP_ZONE_SOURCE_ENTRY ...
@@ -927,6 +903,7 @@ void TemplateWizard::accept ()
 		fileInfo.setFile ( m_listDropZones[t]->qsFileName );
 		// Next we take care of the geometry
 		iWidth = iHeight = 0;
+		// the pixmap should have the real extensions of the Object
 		if ( m_listDropZones[t]->pPixmap ) {
 		  iWidth  = (int) ( m_listDropZones[t]->pPixmap->width ( ) / m_fScale + 0.5 );
 		  iHeight = (int) ( m_listDropZones[t]->pPixmap->height( ) / m_fScale + 0.5 );
@@ -945,7 +922,7 @@ void TemplateWizard::accept ()
 		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BUTTON+").arg(i), QString ("ButtonObject"));
 		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_GEOMETRY+").arg(i), qsGeometry);
 		qsType = "ImageObject"; // default
-		if ( m_listDropZones[t]->bMovie)
+		if ( m_listDropZones[t]->bMovie )
 		  qsType = "MovieObject";
 		// Note we do not want to change Frames or text ...
 		if ( m_listDropZones[t]->iType == DropZone::TextObject )
@@ -975,39 +952,40 @@ void TemplateWizard::accept ()
 	// In case we missed one ...
 	m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_SOURCE_ENTRY+"), qsEntryName);
 
-	//printf ( "\n\n%s\n\n", m_qsXMLDVDMenu.ascii ( ) );
 	if (listAddMovies.count())
 		m_pDVDAuthor->addMovieList (listAddMovies, &qsEntryName);
 
+	// Lastly we replace <MenuSound> with a real deal 
+	handleMenuAudio ( );
+
 	QDomDocument domDoc;
 	int iRow, iCol;
 	QString qsError;
 
 	iRow = iCol = 0;
 	domDoc.setContent (m_qsXMLDVDMenu, true, &qsError, &iRow, &iCol);
-	// printf ("\n\n%s\n\n", (const char *)m_qsXMLDVDMenu);
+	//printf ("\n\n%s\n\n", (const char *)m_qsXMLDVDMenu);
 	QDomElement  menuElement = domDoc.documentElement();
-	if (m_pDVDMenu)
-		delete m_pDVDMenu;
 
+	float fLoadVersion = m_qsTemplateVersion.toFloat ( );
 	// if the menu exist we take this one over
-	m_pDVDMenu = m_pDVDAuthor->getSubMenuByName(m_pComboMenu->currentText());
-	if ( m_pDVDMenu )	{
+	DVDMenu *pDVDMenu = m_pDVDAuthor->getSubMenuByName(m_pComboMenu->currentText());
+	if ( pDVDMenu )	{
 		qsMenuName = m_pComboMenu->currentText();
-		m_pDVDMenu->clear ();
-		m_pDVDMenu->readProjectFile(menuElement);
-		m_pDVDMenu->getInterface()->qsMenuName = qsMenuName;
-		m_pDVDMenu->setTabLabel (qsMenuName);
-		m_pDVDMenu->updateDVDMenu();
+		pDVDMenu->clear ();
+		pDVDMenu->readProjectFile(menuElement, fLoadVersion);
+		pDVDMenu->getInterface()->qsMenuName = qsMenuName;
+		pDVDMenu->setTabLabel (qsMenuName);
+		pDVDMenu->updateDVDMenu();
 	}
 	else	{ // Otherwise we will create a new menu.
-		m_pDVDMenu = new DVDMenu(m_pDVDAuthor);
+		pDVDMenu = new DVDMenu(m_pDVDAuthor);
 		qsMenuName = m_pDVDAuthor->getUniqueMenuTitle (m_pComboMenu->currentText(), 0);
-		m_pDVDMenu->readProjectFile(menuElement);
-		m_pDVDMenu->getInterface()->qsMenuName = qsMenuName;
-		m_pDVDMenu->setTabLabel (qsMenuName);
-		m_pDVDMenu->updateDVDMenu();
-		m_pDVDAuthor->addDVDMenu(m_pDVDMenu);
+		pDVDMenu->readProjectFile ( menuElement, fLoadVersion );
+		pDVDMenu->getInterface    ( )->qsMenuName = qsMenuName;
+		pDVDMenu->setTabLabel     ( qsMenuName );
+		pDVDMenu->updateDVDMenu   ( );
+		m_pDVDAuthor->addDVDMenu  ( pDVDMenu );
 	}
 	Global::qsCurrentPath = qsCurrentPath;
 
@@ -1015,10 +993,122 @@ void TemplateWizard::accept ()
 	m_pDVDAuthor->slotUpdateStructure ();
 	// Here we have to create the SoourceFileEntry for the DVDAuthorObject
 	// Note, the SourceFileEntry holds N SourceFileInfo's
+	refreshMovieButtons ( pDVDMenu );
 	QWizard::accept();
 	QTimer::singleShot (10, m_pDVDAuthor, SLOT(slotDeleteTemplateWizard()));
 	myCursor = QCursor(QCursor::ArrowCursor);
 	setCursor(myCursor);
 }
 
+void TemplateWizard::refreshMovieButtons ( DVDMenu *pDVDMenu )
+{
+  // This function will get the right screenshot for those buttons that were 
+  // created from the Media pool (Left side) and have a thumbnail which is
+  // NOT the first frame.
 
+  uint t, i;
+  MenuObject     *pMenuObject     = NULL;
+  MovieObject    *pMovieObject    = NULL;
+  ButtonObject   *pButtonObject   = NULL;
+  SourceFileInfo *pSourceFileInfo = NULL;
+  QValueList<ButtonObject *> listOfButtons;
+  if ( pDVDMenu ) {
+    listOfButtons = pDVDMenu->getButtons ( );
+    for ( t=0; t<listOfButtons.count ( ); t++ ) {
+      pButtonObject = listOfButtons[t];
+      pSourceFileInfo = pButtonObject->sourceFileInfo ( );
+      if ( pSourceFileInfo && pSourceFileInfo->iMSecPreview > 0 ) {
+	for ( i=0; i<pButtonObject->getNormalCount ( ); i++ ) {
+	  pMenuObject = pButtonObject->getNormal ( i );
+	  if ( pMenuObject && pMenuObject->objectType ( ) == QString ( MOVIE_OBJECT ) ) {
+	    pMovieObject = (MovieObject *)pMenuObject;
+	    if ( pMovieObject->msecPreview   ( ) != pSourceFileInfo->iMSecPreview ) {
+	      pMovieObject->setMSecPreview   ( pSourceFileInfo->iMSecPreview );
+	      MediaCreator::unregisterFromMediaScanner ( pMovieObject );
+	      MediaCreator::registerWithMediaScanner   ( pMovieObject, pMovieObject->fileName ( ), pMovieObject->previewImage ( ), pSourceFileInfo->iMSecPreview );
+	    }
+	  }
+	}
+      }
+    }
+  }
+}
+
+void TemplateWizard::adjustPixmapHeight ( QPixmap *pPixmap, QString &qsButtonXml )
+{
+  if ( ( ! pPixmap ) || ( qsButtonXml.length ( ) < 1 ) )
+    return;
+  // This function will filter the MenuObject Height attribute out of the ButtonXml
+  // and replace it with the properly calculated Height for the dropped in Image/Movie.
+  QRegExp rx, rx1;
+  QString qsPattern,  qsMenuObjectXml, qsHeight;
+  int iPos, iHeight = (int)((float)pPixmap->height ( ) / m_fScale + 0.5 );
+  if ( iHeight < 1 )
+    return;
+  
+  //printf ( "\n\n%s\n----------------\n", qsButtonXml.ascii ( ) );
+  qsHeight = QString ( "Height=\"%1\"" ).arg ( iHeight );
+
+  qsPattern = QString ( "MenuObject[^>]*>.*</MenuObject>" );
+  rx.setPattern  ( qsPattern );
+  rx1.setPattern ( "Height=\".*\"" );
+  // A button usually has three objects
+  if ( rx.search ( qsButtonXml ) > -1 ) {
+    rx.setMinimal  ( true );
+    rx1.setMinimal ( true );
+    iPos = 0;
+    while ( iPos >= 0 ) {
+      iPos = rx.search ( qsButtonXml, iPos );
+      if ( iPos > -1 ) {
+	qsMenuObjectXml = rx.cap ( 0 );
+	//printf ( "--------------------------\n%s\n\n", qsMenuObjectXml.ascii ( ) );
+	qsMenuObjectXml.replace ( rx1, qsHeight );
+	iPos += rx.matchedLength ( );
+	qsButtonXml.replace ( rx.cap ( 0 ), qsMenuObjectXml );
+      }
+    }
+  }
+  //printf ( "--------------------------\n%s\n\n", qsButtonXml.ascii ( ) );
+}
+
+void TemplateWizard::handleMenuAudio ( )
+{
+  int iPos;
+  QRegExp rx;
+  QString qsMenuSound, qsSoundFile;
+  QStringList listSoundFiles;
+
+  rx.setPattern ( "<MenuSound>.*</MenuSound>" );
+  if ( rx.search ( m_qsXMLDVDMenu ) > -1 ) {
+    rx.setMinimal ( true );
+
+    iPos = 0;
+    while ( iPos >= 0 ) {
+      iPos = rx.search ( m_qsXMLDVDMenu, iPos );
+      if ( iPos > -1 ) {
+	qsSoundFile = rx.cap ( 0 );  // get the full ImageObject - Tag 
+	qsSoundFile = qsSoundFile.remove  (  "<MenuSound>" );
+	qsSoundFile = qsSoundFile.remove  ( "</MenuSound>" );
+	listSoundFiles.append ( qsSoundFile );
+	iPos += rx.matchedLength ( );
+      }
+    }
+    
+    if ( listSoundFiles.count () > 0 ) {
+      // Okay, we add the sound source
+      m_pDVDAuthor->checkForNewProject ( );
+      m_pDVDAuthor->addSound ( listSoundFiles );
+      // And the created SourceFileEntry will be the last in the list.
+      SourceFileEntry *pEntry = m_pDVDAuthor->sourceFileEntry ( m_pDVDAuthor->sourceFileCount ( ) - 1 );
+      if ( pEntry && pEntry->bSoundSource ) {
+	QString qsEntryName = pEntry->qsDisplayName;
+	qsEntryName = qsEntryName.replace ( "<", "&lt;" );
+	qsEntryName = qsEntryName.replace ( ">", "&gt;" );
+	qsMenuSound = "   <MenuSound>" + qsEntryName + "</MenuSound>";
+      }
+    }
+  }
+  rx.setMinimal ( false );
+  // Finally, we replace the entry with one that the DVDMenu can chew on.
+  m_qsXMLDVDMenu.replace ( rx, qsMenuSound );
+}
