@@ -40,7 +40,8 @@ public:
 	virtual void setFont               ( QFont   & );
 	virtual void setText               ( QString & );
 	virtual void setTextAlign          ( QPoint  & );
-	virtual void setStyleStrategy      ( int );
+	virtual void setWordBreak          ( bool );
+	virtual void setStyleStrategy      ( int  );
 	virtual void setForegroundColor    ( const Rgba & );
 	virtual void setBackgroundColor    ( const Rgba & );
 	virtual QFont   &getFont           ( );
@@ -71,6 +72,7 @@ protected:
 	Rgba        m_colorForeground;
 	Rgba        m_colorBackground;
 	int         m_iStyleStrategy;
+	bool        m_bAllowWordBreak; // don't need ot be stored. Only set after DialogTextFont
 };
 
 
