@@ -405,7 +405,8 @@ QString Utils::iso639 (QString qsCode, bool bReverse, int iWhich )
 	uint t, iCount;
 	int iReverse;
 	QString qsReturn;
-	iCount = (int)(sizeof (arrayCountry) / (sizeof (char) * 36 * 2));
+	iCount = (int)(sizeof (arrayCountry) / (sizeof (arrayCountry[0]) * 2)); 
+	//iCount = (int)(sizeof (arrayCountry) / (sizeof (char) * 36 * 2));
 	// Determines forward/backward looking up.
 	iReverse = 0;
 	if (bReverse)
